/*
This file was automatically generated from multiple sources,
some of which included stylesheets from mosra/m.css.
The license for that project is as follows:

Copyright © 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024
          Vladimír Vondruš <mosra@centrum.cz> and contributors

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the "Software"),
to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense,
and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
DEALINGS IN THE SOFTWARE.
*/

/*==== https://fonts.googleapis.com/css?family=Source+Sans+Pro:400,400i,600,600i%7CSource+Code+Pro:400,400i,600 ======*/
@font-face {
font-family: 'Source Code Pro';
font-style: italic;
font-weight: 400;
src: url('fonts/HI_jiYsKILxRpg3hIP6sJ7fM7PqlOPHYvDP_W9O7GQTTbI1bQ10YVJg.woff2') format('woff2');
unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
}
@font-face {
font-family: 'Source Code Pro';
font-style: italic;
font-weight: 400;
src: url('fonts/HI_jiYsKILxRpg3hIP6sJ7fM7PqlOPHYvDP_W9O7GQTTbI1bSl0YVJg.woff2') format('woff2');
unicode-range: U+0301, U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
}
@font-face {
font-family: 'Source Code Pro';
font-style: italic;
font-weight: 400;
src: url('fonts/HI_jiYsKILxRpg3hIP6sJ7fM7PqlOPHYvDP_W9O7GQTTbI1bQl0YVJg.woff2') format('woff2');
unicode-range: U+1F00-1FFF;
}
@font-face {
font-family: 'Source Code Pro';
font-style: italic;
font-weight: 400;
src: url('fonts/HI_jiYsKILxRpg3hIP6sJ7fM7PqlOPHYvDP_W9O7GQTTbI1bTV0YVJg.woff2') format('woff2');
unicode-range: U+0370-0377, U+037A-037F, U+0384-038A, U+038C, U+038E-03A1, U+03A3-03FF;
}
@font-face {
font-family: 'Source Code Pro';
font-style: italic;
font-weight: 400;
src: url('fonts/HI_jiYsKILxRpg3hIP6sJ7fM7PqlOPHYvDP_W9O7GQTTbI1bQV0YVJg.woff2') format('woff2');
unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+0300-0301, U+0303-0304, U+0308-0309, U+0323, U+0329, U+1EA0-1EF9, U+20AB;
}
@font-face {
font-family: 'Source Code Pro';
font-style: italic;
font-weight: 400;
src: url('fonts/HI_jiYsKILxRpg3hIP6sJ7fM7PqlOPHYvDP_W9O7GQTTbI1bQF0YVJg.woff2') format('woff2');
unicode-range: U+0100-02AF, U+0304, U+0308, U+0329, U+1E00-1E9F, U+1EF2-1EFF, U+2020, U+20A0-20AB, U+20AD-20C0, U+2113, U+2C60-2C7F, U+A720-A7FF;
}
@font-face {
font-family: 'Source Code Pro';
font-style: italic;
font-weight: 400;
src: url('fonts/HI_jiYsKILxRpg3hIP6sJ7fM7PqlOPHYvDP_W9O7GQTTbI1bTl0Y.woff2') format('woff2');
unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+0304, U+0308, U+0329, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}
@font-face {
font-family: 'Source Code Pro';
font-style: normal;
font-weight: 400;
src: url('fonts/HI_SiYsKILxRpg3hIP6sJ7fM7PqlMOvWjMY.woff2') format('woff2');
unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
}
@font-face {
font-family: 'Source Code Pro';
font-style: normal;
font-weight: 400;
src: url('fonts/HI_SiYsKILxRpg3hIP6sJ7fM7PqlOevWjMY.woff2') format('woff2');
unicode-range: U+0301, U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
}
@font-face {
font-family: 'Source Code Pro';
font-style: normal;
font-weight: 400;
src: url('fonts/HI_SiYsKILxRpg3hIP6sJ7fM7PqlMevWjMY.woff2') format('woff2');
unicode-range: U+1F00-1FFF;
}
@font-face {
font-family: 'Source Code Pro';
font-style: normal;
font-weight: 400;
src: url('fonts/HI_SiYsKILxRpg3hIP6sJ7fM7PqlPuvWjMY.woff2') format('woff2');
unicode-range: U+0370-0377, U+037A-037F, U+0384-038A, U+038C, U+038E-03A1, U+03A3-03FF;
}
@font-face {
font-family: 'Source Code Pro';
font-style: normal;
font-weight: 400;
src: url('fonts/HI_SiYsKILxRpg3hIP6sJ7fM7PqlMuvWjMY.woff2') format('woff2');
unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+0300-0301, U+0303-0304, U+0308-0309, U+0323, U+0329, U+1EA0-1EF9, U+20AB;
}
@font-face {
font-family: 'Source Code Pro';
font-style: normal;
font-weight: 400;
src: url('fonts/HI_SiYsKILxRpg3hIP6sJ7fM7PqlM-vWjMY.woff2') format('woff2');
unicode-range: U+0100-02AF, U+0304, U+0308, U+0329, U+1E00-1E9F, U+1EF2-1EFF, U+2020, U+20A0-20AB, U+20AD-20C0, U+2113, U+2C60-2C7F, U+A720-A7FF;
}
@font-face {
font-family: 'Source Code Pro';
font-style: normal;
font-weight: 400;
src: url('fonts/HI_SiYsKILxRpg3hIP6sJ7fM7PqlPevW.woff2') format('woff2');
unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+0304, U+0308, U+0329, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}
@font-face {
font-family: 'Source Code Pro';
font-style: normal;
font-weight: 600;
src: url('fonts/HI_SiYsKILxRpg3hIP6sJ7fM7PqlMOvWjMY.woff2') format('woff2');
unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
}
@font-face {
font-family: 'Source Code Pro';
font-style: normal;
font-weight: 600;
src: url('fonts/HI_SiYsKILxRpg3hIP6sJ7fM7PqlOevWjMY.woff2') format('woff2');
unicode-range: U+0301, U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
}
@font-face {
font-family: 'Source Code Pro';
font-style: normal;
font-weight: 600;
src: url('fonts/HI_SiYsKILxRpg3hIP6sJ7fM7PqlMevWjMY.woff2') format('woff2');
unicode-range: U+1F00-1FFF;
}
@font-face {
font-family: 'Source Code Pro';
font-style: normal;
font-weight: 600;
src: url('fonts/HI_SiYsKILxRpg3hIP6sJ7fM7PqlPuvWjMY.woff2') format('woff2');
unicode-range: U+0370-0377, U+037A-037F, U+0384-038A, U+038C, U+038E-03A1, U+03A3-03FF;
}
@font-face {
font-family: 'Source Code Pro';
font-style: normal;
font-weight: 600;
src: url('fonts/HI_SiYsKILxRpg3hIP6sJ7fM7PqlMuvWjMY.woff2') format('woff2');
unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+0300-0301, U+0303-0304, U+0308-0309, U+0323, U+0329, U+1EA0-1EF9, U+20AB;
}
@font-face {
font-family: 'Source Code Pro';
font-style: normal;
font-weight: 600;
src: url('fonts/HI_SiYsKILxRpg3hIP6sJ7fM7PqlM-vWjMY.woff2') format('woff2');
unicode-range: U+0100-02AF, U+0304, U+0308, U+0329, U+1E00-1E9F, U+1EF2-1EFF, U+2020, U+20A0-20AB, U+20AD-20C0, U+2113, U+2C60-2C7F, U+A720-A7FF;
}
@font-face {
font-family: 'Source Code Pro';
font-style: normal;
font-weight: 600;
src: url('fonts/HI_SiYsKILxRpg3hIP6sJ7fM7PqlPevW.woff2') format('woff2');
unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+0304, U+0308, U+0329, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: italic;
font-weight: 400;
src: url('fonts/6xK1dSBYKcSV-LCoeQqfX1RYOo3qPZ7qsDJT9g.woff2') format('woff2');
unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: italic;
font-weight: 400;
src: url('fonts/6xK1dSBYKcSV-LCoeQqfX1RYOo3qPZ7jsDJT9g.woff2') format('woff2');
unicode-range: U+0301, U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: italic;
font-weight: 400;
src: url('fonts/6xK1dSBYKcSV-LCoeQqfX1RYOo3qPZ7rsDJT9g.woff2') format('woff2');
unicode-range: U+1F00-1FFF;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: italic;
font-weight: 400;
src: url('fonts/6xK1dSBYKcSV-LCoeQqfX1RYOo3qPZ7ksDJT9g.woff2') format('woff2');
unicode-range: U+0370-0377, U+037A-037F, U+0384-038A, U+038C, U+038E-03A1, U+03A3-03FF;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: italic;
font-weight: 400;
src: url('fonts/6xK1dSBYKcSV-LCoeQqfX1RYOo3qPZ7osDJT9g.woff2') format('woff2');
unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+0300-0301, U+0303-0304, U+0308-0309, U+0323, U+0329, U+1EA0-1EF9, U+20AB;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: italic;
font-weight: 400;
src: url('fonts/6xK1dSBYKcSV-LCoeQqfX1RYOo3qPZ7psDJT9g.woff2') format('woff2');
unicode-range: U+0100-02AF, U+0304, U+0308, U+0329, U+1E00-1E9F, U+1EF2-1EFF, U+2020, U+20A0-20AB, U+20AD-20C0, U+2113, U+2C60-2C7F, U+A720-A7FF;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: italic;
font-weight: 400;
src: url('fonts/6xK1dSBYKcSV-LCoeQqfX1RYOo3qPZ7nsDI.woff2') format('woff2');
unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+0304, U+0308, U+0329, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: italic;
font-weight: 600;
src: url('fonts/6xKwdSBYKcSV-LCoeQqfX1RYOo3qPZY4lCdh18Smxg.woff2') format('woff2');
unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: italic;
font-weight: 600;
src: url('fonts/6xKwdSBYKcSV-LCoeQqfX1RYOo3qPZY4lCdo18Smxg.woff2') format('woff2');
unicode-range: U+0301, U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: italic;
font-weight: 600;
src: url('fonts/6xKwdSBYKcSV-LCoeQqfX1RYOo3qPZY4lCdg18Smxg.woff2') format('woff2');
unicode-range: U+1F00-1FFF;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: italic;
font-weight: 600;
src: url('fonts/6xKwdSBYKcSV-LCoeQqfX1RYOo3qPZY4lCdv18Smxg.woff2') format('woff2');
unicode-range: U+0370-0377, U+037A-037F, U+0384-038A, U+038C, U+038E-03A1, U+03A3-03FF;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: italic;
font-weight: 600;
src: url('fonts/6xKwdSBYKcSV-LCoeQqfX1RYOo3qPZY4lCdj18Smxg.woff2') format('woff2');
unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+0300-0301, U+0303-0304, U+0308-0309, U+0323, U+0329, U+1EA0-1EF9, U+20AB;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: italic;
font-weight: 600;
src: url('fonts/6xKwdSBYKcSV-LCoeQqfX1RYOo3qPZY4lCdi18Smxg.woff2') format('woff2');
unicode-range: U+0100-02AF, U+0304, U+0308, U+0329, U+1E00-1E9F, U+1EF2-1EFF, U+2020, U+20A0-20AB, U+20AD-20C0, U+2113, U+2C60-2C7F, U+A720-A7FF;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: italic;
font-weight: 600;
src: url('fonts/6xKwdSBYKcSV-LCoeQqfX1RYOo3qPZY4lCds18Q.woff2') format('woff2');
unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+0304, U+0308, U+0329, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: normal;
font-weight: 400;
src: url('fonts/6xK3dSBYKcSV-LCoeQqfX1RYOo3qNa7lqDY.woff2') format('woff2');
unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: normal;
font-weight: 400;
src: url('fonts/6xK3dSBYKcSV-LCoeQqfX1RYOo3qPK7lqDY.woff2') format('woff2');
unicode-range: U+0301, U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: normal;
font-weight: 400;
src: url('fonts/6xK3dSBYKcSV-LCoeQqfX1RYOo3qNK7lqDY.woff2') format('woff2');
unicode-range: U+1F00-1FFF;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: normal;
font-weight: 400;
src: url('fonts/6xK3dSBYKcSV-LCoeQqfX1RYOo3qO67lqDY.woff2') format('woff2');
unicode-range: U+0370-0377, U+037A-037F, U+0384-038A, U+038C, U+038E-03A1, U+03A3-03FF;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: normal;
font-weight: 400;
src: url('fonts/6xK3dSBYKcSV-LCoeQqfX1RYOo3qN67lqDY.woff2') format('woff2');
unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+0300-0301, U+0303-0304, U+0308-0309, U+0323, U+0329, U+1EA0-1EF9, U+20AB;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: normal;
font-weight: 400;
src: url('fonts/6xK3dSBYKcSV-LCoeQqfX1RYOo3qNq7lqDY.woff2') format('woff2');
unicode-range: U+0100-02AF, U+0304, U+0308, U+0329, U+1E00-1E9F, U+1EF2-1EFF, U+2020, U+20A0-20AB, U+20AD-20C0, U+2113, U+2C60-2C7F, U+A720-A7FF;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: normal;
font-weight: 400;
src: url('fonts/6xK3dSBYKcSV-LCoeQqfX1RYOo3qOK7l.woff2') format('woff2');
unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+0304, U+0308, U+0329, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: normal;
font-weight: 600;
src: url('fonts/6xKydSBYKcSV-LCoeQqfX1RYOo3i54rwmhduz8A.woff2') format('woff2');
unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: normal;
font-weight: 600;
src: url('fonts/6xKydSBYKcSV-LCoeQqfX1RYOo3i54rwkxduz8A.woff2') format('woff2');
unicode-range: U+0301, U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: normal;
font-weight: 600;
src: url('fonts/6xKydSBYKcSV-LCoeQqfX1RYOo3i54rwmxduz8A.woff2') format('woff2');
unicode-range: U+1F00-1FFF;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: normal;
font-weight: 600;
src: url('fonts/6xKydSBYKcSV-LCoeQqfX1RYOo3i54rwlBduz8A.woff2') format('woff2');
unicode-range: U+0370-0377, U+037A-037F, U+0384-038A, U+038C, U+038E-03A1, U+03A3-03FF;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: normal;
font-weight: 600;
src: url('fonts/6xKydSBYKcSV-LCoeQqfX1RYOo3i54rwmBduz8A.woff2') format('woff2');
unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+0300-0301, U+0303-0304, U+0308-0309, U+0323, U+0329, U+1EA0-1EF9, U+20AB;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: normal;
font-weight: 600;
src: url('fonts/6xKydSBYKcSV-LCoeQqfX1RYOo3i54rwmRduz8A.woff2') format('woff2');
unicode-range: U+0100-02AF, U+0304, U+0308, U+0329, U+1E00-1E9F, U+1EF2-1EFF, U+2020, U+20A0-20AB, U+20AD-20C0, U+2113, U+2C60-2C7F, U+A720-A7FF;
}
@font-face {
font-family: 'Source Sans Pro';
font-style: normal;
font-weight: 600;
src: url('fonts/6xKydSBYKcSV-LCoeQqfX1RYOo3i54rwlxdu.woff2') format('woff2');
unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+0304, U+0308, U+0329, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}
/*==== m-theme-dark.css ==============================================================================================*/
.poxy-theme-dark {
--font: 'Source Sans Pro', sans-serif;
--code-font: 'Source Code Pro', monospace;
--font-size: 16px;
--code-font-size: 0.9em;
--line-height: normal;
--paragraph-indent: 1.5rem;
--paragraph-align: justify;
--link-decoration: underline;
--link-decoration-nav: none;
--link-decoration-heading: none;
--nav-brand-case: uppercase;
--nav-menu-case: none;
--nav-heading-case: uppercase;
--nav-categories-case: lowercase;
--landing-header-case: lowercase;
--heading-font-weight: 600;
--border-radius: 0.2rem;
--background-color: #2f363f;
--color: #dcdcdc;
--line-color: #405363;
--link-color: #5b9dd9;
--link-active-color: #a5c9ea;
--mark-color: #2f83cc;
--mark-background-color: #c7cf2f;
--button-background-color: #22272e;
--code-color: #e6e6e6;
--code-background-color: #282e36;
--code-note-background-color: rgba(34, 39, 46, 0.5);
--console-color: #fcfcfc;
--console-background-color: #1a1c1d;
--header-border-width: 0 0 0.25rem 0;
--header-color: #ffffff;
--header-breadcrumb-color: #747474;
--header-background-color: #22272e;
--header-background-color-landing: rgba(34, 39, 46, 0.75);
--header-background-color-jumbo: rgba(34, 39, 46, 0.25);
--header-link-color: #ffffff;
--header-link-active-color: #a5c9ea;
--header-link-current-color: #5b9dd9;
--header-link-active-background-color: #292f37;
--header-link-active-background-color-semi: rgba(41, 47, 55, 0.5);
--footer-font-size: 0.85rem;
--footer-color: #c5c5c5;
--footer-background-color: #444e5c;
--footer-link-color: #ffffff;
--footer-link-active-color: #a5c9ea;
--cover-image-background-color: #0f1217;
--search-overlay-color: var(--header-background-color-landing);
--search-background-color: var(--header-background-color);
--article-header-color: #f0f0f0;
--article-footer-color: #c5c5c5;
--article-heading-color: #a5c9ea;
--article-heading-active-color: #dcdcdc;
--navpanel-link-color: #ffffff;
--navpanel-link-active-color: #a5c9ea;
--plot-background-color: #34424d;
--plot-error-color: #ffffff;
--default-color: #dcdcdc;
--default-link-active-color: #a5c9ea;
--default-filled-color: #dcdcdc;
--default-filled-background-color: #34424d;
--default-filled-link-color: #5b9dd9;
--default-filled-link-active-color: #a5c9ea;
--primary-color: #a5c9ea;
--primary-link-active-color: #dcdcdc;
--primary-filled-color: #2f363f;
--primary-filled-background-color: #a5c2db;
--primary-filled-link-color: #2a75b6;
--primary-filled-link-active-color: #2f363f;
--success-color: #3bd267;
--success-link-active-color: #acecbe;
--success-filled-color: #acecbe;
--success-filled-background-color: #2a703f;
--success-filled-link-color: #3bd267;
--success-filled-link-active-color: #acecbe;
--warning-color: #c7cf2f;
--warning-link-active-color: #e9ecae;
--warning-filled-color: #e9ecae;
--warning-filled-background-color: #6d702a;
--warning-filled-link-color: #b8bf2b;
--warning-filled-link-active-color: #e9ecae;
--danger-color: #cd3431;
--danger-link-active-color: #ff9391;
--danger-filled-color: #ff9391;
--danger-filled-background-color: #702b2a;
--danger-filled-link-color: #d85c59;
--danger-filled-link-active-color: #ff9391;
--info-color: #2f83cc;
--info-link-active-color: #5297d7;
--info-filled-color: #a5caeb;
--info-filled-background-color: #2a4f70;
--info-filled-link-color: #5297d7;
--info-filled-link-active-color: #a5caeb;
--dim-color: #747474;
--dim-link-color: #acacac;
--dim-link-active-color: #747474;
--dim-filled-color: #747474;
--dim-filled-background-color: #2d3236;
--dim-filled-link-color: #acacac;
--dim-filled-link-active-color: #747474;
--dim-button-active-color: #acacac;
}
/*==== poxy-theme-dark.css ===========================================================================================*/
.poxy-theme-dark {
--code-font: "Consolas", "Source Code Pro", monospace;
--code-color-comments: #57a64a;
--code-color-keywords: #569cd6;
--code-color-identifiers: #e6e6e6;
--code-color-typenames: #4ec9b0;
--code-color-namespaces: #8c8c8c;
--code-color-operators: #aaaaaa;
--code-color-punctuation: #787878;
--code-color-numbers: #b5cea8;
--code-color-strings: #d69d85;
--code-color-escapes: #e07cdc;
--code-color-preprocessor: #787878;
--code-color-macros: #beb7ff;
--code-color-functions: #dcdcaa;
--special-color: #b65ad7;
--special-link-active-color: #e4a8ff;
--special-filled-color: #ce97e8;
--special-filled-background-color: #532f64;
--special-filled-link-color: #a061bd;
--special-filled-link-active-color: #e4a8ff;
--detail-section-header-color: var(--header-background-color);
--detail-section-background-color: rgba(0, 0, 0, 0.06);
--sponsor-color: #ff69b4;
}
/*==== m-theme-light.css =============================================================================================*/
.poxy-theme-light {
--theme-hue: 210;
--theme-saturation: 100%;
--theme-luminosity: 50%;
--theme-color: hsl(var(--theme-hue), var(--theme-saturation), var(--theme-luminosity));
--theme-text1: hsl(var(--theme-hue), var(--theme-saturation), 10%);
--theme-text2: hsl(var(--theme-hue), 30%, 30%);
--theme-surface1: hsl(var(--theme-hue), 25%, 90%);
--theme-surface2: hsl(var(--theme-hue), 20%, 99%);
--theme-surface3: hsl(var(--theme-hue), calc(var(--theme-saturation) * 0.3), 85%);
--theme-surface4: hsl(var(--theme-hue), 20%, 93%);
--theme-surface5: hsl(var(--theme-hue), calc(var(--theme-saturation) * 0.5), 55%);
--theme-surface6: hsl(var(--theme-hue), calc(var(--theme-saturation) * 0.5), 68%);
--theme-surface7: hsl(var(--theme-hue), var(--theme-saturation), 90%);
--theme-surface8: hsl(var(--theme-hue), calc(var(--theme-saturation) * 0.8), 50%);
}
.poxy-theme-light {
--font: 'Source Sans Pro', sans-serif;
--code-font: 'Source Code Pro', monospace;
--font-size: 16px;
--code-font-size: 0.9em;
--line-height: normal;
--paragraph-indent: 1.5rem;
--paragraph-align: justify;
--link-decoration: underline;
--link-decoration-nav: none;
--link-decoration-heading: none;
--nav-brand-case: uppercase;
--nav-menu-case: none;
--nav-heading-case: uppercase;
--nav-categories-case: lowercase;
--landing-header-case: lowercase;
--heading-font-weight: 600;
--border-radius: 0.2rem;
--background-color: var(--theme-surface4);
--color: var(--theme-text1);
--line-color: var(--theme-surface6);
--link-color: var(--theme-surface8);
--link-active-color: var(--theme-text2);
--mark-color: #2f83cc;
--mark-background-color: #c7cf2f;
--button-background-color: #22272e;
--code-color: var(--theme-text1);
--code-background-color: var(--theme-surface2);
--code-note-background-color: hsla(var(--theme-hue), var(--theme-saturation), 99%, 0.7);
--console-color: #fcfcfc;
--console-background-color: #1a1c1d;
--header-border-width: 0 0 0.25rem 0;
--header-color: var(--theme-surface1);
--header-breadcrumb-color: var(--theme-surface1);
--header-background-color: var(--theme-surface5);
--header-background-color-landing: rgba(34, 39, 46, 0.75);
--header-background-color-jumbo: rgba(34, 39, 46, 0.25);
--header-link-color: var(--theme-surface2);
--header-link-active-color: var(--theme-surface7);
--header-link-current-color: var(--theme-surface7);
--header-link-active-background-color: var(--theme-surface6);
--header-link-active-background-color-semi: #ebeaea80;
--footer-font-size: 0.85rem;
--footer-color: var(--theme-text2);
--footer-background-color: var(--theme-surface3);
--footer-link-color: var(--theme-text1);
--footer-link-active-color:var(--theme-text2);
--cover-image-background-color: #0f1217;
--search-overlay-color: hsla(var(--theme-hue), calc(var(--theme-saturation) * 0.5), 75%, 85%);
--search-background-color: var(--theme-surface4);
--article-header-color: #f0f0f0;
--article-footer-color: #c5c5c5;
--article-heading-color: var(--theme-surface8);
--article-heading-active-color: var(--theme-text2);
--navpanel-link-color: #ffffff;
--navpanel-link-active-color: #5787EF;
--plot-background-color: #ced8de;
--plot-error-color: #ffffff;
--default-color: var(--theme-text1);
--default-link-active-color: var(--link-active-color);
--default-filled-color: #151414;
--default-filled-background-color: var(--theme-surface3);
--default-filled-link-color: #134ECD;
--default-filled-link-active-color: #5787EF;
--primary-hue: var(--theme-hue);
--primary-saturation: var(--theme-saturation);
--primary-luminosity: calc(var(--theme-luminosity) * 1.05);
--primary-color: hsl(var(--primary-hue), var(--primary-saturation), var(--primary-luminosity));
--primary-link-active-color: hsl(var(--primary-hue), var(--primary-saturation), calc(var(--primary-luminosity) * 0.7));
--primary-filled-color: hsl(var(--primary-hue), var(--primary-saturation), 25%);
--primary-filled-background-color: hsl(var(--primary-hue), var(--primary-saturation), calc(var(--primary-luminosity) * 1.7));
--primary-filled-link-color: hsl(var(--primary-hue), var(--primary-saturation), 50%);
--primary-filled-link-active-color: var(--primary-filled-color);
--success-hue: 138;
--success-saturation: 40%;
--success-luminosity: 45%;
--success-color: hsl(var(--success-hue), var(--success-saturation), var(--success-luminosity));
--success-link-active-color: hsl(var(--success-hue), var(--success-saturation), calc(var(--success-luminosity) * 0.7));
--success-filled-color: hsl(var(--success-hue), var(--success-saturation), 25%);
--success-filled-background-color: hsl(var(--success-hue), calc(var(--success-saturation) * 0.9), calc(var(--success-luminosity) * 1.8));
--success-filled-link-color: hsl(var(--success-hue), calc(var(--success-saturation) * 0.8), 40%);
--success-filled-link-active-color: var(--success-filled-color);
--warning-hue: 53;
--warning-saturation: 50%;
--warning-luminosity: 44%;
--warning-color: hsl(var(--warning-hue), var(--warning-saturation), var(--warning-luminosity));
--warning-link-active-color: hsl(var(--warning-hue), var(--warning-saturation), calc(var(--warning-luminosity) * 0.7));
--warning-filled-color: hsl(var(--warning-hue), var(--warning-saturation), 20%);
--warning-filled-background-color: hsl(var(--warning-hue), calc(var(--warning-saturation) * 0.8), calc(var(--warning-luminosity) * 1.8));
--warning-filled-link-color: hsl(var(--warning-hue), calc(var(--warning-saturation) * 0.6), 40%);
--warning-filled-link-active-color: var(--warning-filled-color);
--danger-hue: 0;
--danger-saturation: 70%;
--danger-luminosity: 50%;
--danger-color: hsl(var(--danger-hue), var(--danger-saturation), var(--danger-luminosity));
--danger-link-active-color: hsl(var(--danger-hue), var(--danger-saturation), calc(var(--danger-luminosity) * 0.7));
--danger-filled-color: hsl(var(--danger-hue), var(--danger-saturation), 25%);
--danger-filled-background-color: hsl(var(--danger-hue), calc(var(--danger-saturation) * 0.8), calc(var(--danger-luminosity) * 1.75));
--danger-filled-link-color: hsl(var(--danger-hue), calc(var(--danger-saturation) * 0.6), 50%);
--danger-filled-link-active-color: var(--danger-filled-color);
--info-hue: 209;
--info-saturation: 62%;
--info-luminosity: 50%;
--info-color: hsl(var(--info-hue), var(--info-saturation), var(--info-luminosity));
--info-link-active-color: hsl(var(--info-hue), var(--info-saturation), calc(var(--info-luminosity) * 0.7));
--info-filled-color: hsl(var(--info-hue), var(--info-saturation), 25%);
--info-filled-background-color: hsl(var(--info-hue), calc(var(--info-saturation) * 0.8), calc(var(--info-luminosity) * 1.7));
--info-filled-link-color: hsl(var(--info-hue), calc(var(--info-saturation) * 0.6), 50%);
--info-filled-link-active-color: var(--info-filled-color);
--dim-hue: 0;
--dim-saturation: 0%;
--dim-luminosity: 48%;
--dim-color: hsl(var(--dim-hue), var(--dim-saturation), var(--dim-luminosity));
--dim-link-color: #292929;
--dim-link-active-color: hsl(var(--dim-hue), var(--dim-saturation), calc(var(--dim-luminosity) * 0.7));
--dim-filled-color: #656565;
--dim-filled-background-color: #d3d3d3;
--dim-filled-link-color: #292929;
--dim-filled-link-active-color: #7c7c7c;
--dim-button-active-color: #292929;
}
/*==== poxy-theme-light.css ==========================================================================================*/
.poxy-theme-light {
--code-font: "Consolas", "Source Code Pro", monospace;
--code-color-comments: #008000;
--code-color-keywords: #0000ff;
--code-color-identifiers: #151414;
--code-color-typenames: #2b91af;
--code-color-namespaces: #808080;
--code-color-operators: #404040;
--code-color-punctuation: #404040;
--code-color-numbers: #74531f;
--code-color-strings: #a31515;
--code-color-escapes: #b776fb;
--code-color-preprocessor: #808080;
--code-color-macros: #a800d7;
--code-color-functions: #6f5300;
--special-hue: 284;
--special-saturation: 50%;
--special-luminosity: 60%;
--special-color: hsl(var(--special-hue), var(--special-saturation), var(--special-luminosity));
--special-link-active-color: hsl(
var(--special-hue),
var(--special-saturation),
calc(var(--special-luminosity) * 0.7)
);
--special-filled-color: hsl(var(--special-hue), var(--special-saturation), 25%);
--special-filled-background-color: hsl(
var(--special-hue),
calc(var(--special-saturation) * 0.8),
calc(var(--special-luminosity) * 1.4)
);
--special-filled-link-color: hsl(var(--special-hue), calc(var(--special-saturation) * 0.6), 50%);
--special-filled-link-active-color: var(--special-filled-color);
--detail-section-header-color: var(--theme-surface3);
--detail-section-background-color: rgba(255, 255, 255, 0.3);
--sponsor-color: #f8c8dc;
}
/*==== ../mcss/css/m-grid.css ========================================================================================*/
*, ::before, ::after { box-sizing: border-box; }
body { margin: 0; }
.m-container { width: 100%; margin: auto; padding-left: 1rem; padding-right: 1rem; }
.m-row { margin-left: -1rem; margin-right: -1rem; }
.m-row::after { content: ' '; clear: both; display: table; }
.m-row > [class*='m-col-'] { position: relative; padding: 1rem; }
[class*='m-clearfix-']::after { display: block; content: ' '; clear: both; }
[class*='m-show-'] { display: none; }
.m-container-inflate, :not(.m-row) > [class*='m-col-'] { margin-bottom: 1rem; }
.m-container-inflate:last-child, :not(.m-row) > [class*='m-col-']:last-child { margin-bottom: 0; }
.m-container.m-nopad, [class*='m-col-'].m-nopad,
.m-container.m-nopadx, [class*='m-col-'].m-nopadx,
.m-container.m-nopadl, [class*='m-col-'].m-nopadl { padding-left: 0; }
.m-container.m-nopad, [class*='m-col-'].m-nopad,
.m-container.m-nopadx, [class*='m-col-'].m-nopadx,
.m-container.m-nopadr, [class*='m-col-'].m-nopadr { padding-right: 0; }
[class*='m-col-'].m-nopad, [class*='m-col-'].m-nopady, [class*='m-col-'].m-nopadt { padding-top: 0; }
[class*='m-col-'].m-nopad, [class*='m-col-'].m-nopady, [class*='m-col-'].m-nopadb,
.m-container-inflate.m-nopadb { padding-bottom: 0; }
[class*='m-col-t-'] { float: left; }
.m-left-t { padding-right: 1rem; float: left; }
.m-right-t, [class*='m-col-t-'].m-right-t { padding-left: 1rem; float: right; }
.m-center-t, [class*='m-col-t-'].m-center-t { float: none; }
.m-center-t, [class*='m-col-t-'].m-center-t { margin-left: auto; margin-right: auto; float: none; }
.m-col-t-1 { width: calc(1 * 100% / 12); }
.m-col-t-2 { width: calc(2 * 100% / 12); }
.m-col-t-3 { width: calc(3 * 100% / 12); }
.m-col-t-4 { width: calc(4 * 100% / 12); }
.m-col-t-5 { width: calc(5 * 100% / 12); }
.m-col-t-6 { width: calc(6 * 100% / 12); }
.m-col-t-7 { width: calc(7 * 100% / 12); }
.m-col-t-8 { width: calc(8 * 100% / 12); }
.m-col-t-9 { width: calc(9 * 100% / 12); }
.m-col-t-10 { width: calc(10 * 100% / 12); }
.m-col-t-11 { width: calc(11 * 100% / 12); }
.m-col-t-12 { width: calc(12 * 100% / 12); }
.m-push-t-1 { left: calc(1 * 100% / 12); }
.m-push-t-2 { left: calc(2 * 100% / 12); }
.m-push-t-3 { left: calc(3 * 100% / 12); }
.m-push-t-4 { left: calc(4 * 100% / 12); }
.m-push-t-5 { left: calc(5 * 100% / 12); }
.m-push-t-6 { left: calc(6 * 100% / 12); }
.m-push-t-7 { left: calc(7 * 100% / 12); }
.m-push-t-8 { left: calc(8 * 100% / 12); }
.m-push-t-9 { left: calc(9 * 100% / 12); }
.m-push-t-10 { left: calc(10 * 100% / 12); }
.m-push-t-11 { left: calc(11 * 100% / 12); }
.m-pull-t-1 { right: calc(1 * 100% / 12); }
.m-pull-t-2 { right: calc(2 * 100% / 12); }
.m-pull-t-3 { right: calc(3 * 100% / 12); }
.m-pull-t-4 { right: calc(4 * 100% / 12); }
.m-pull-t-5 { right: calc(5 * 100% / 12); }
.m-pull-t-6 { right: calc(6 * 100% / 12); }
.m-pull-t-7 { right: calc(7 * 100% / 12); }
.m-pull-t-8 { right: calc(8 * 100% / 12); }
.m-pull-t-9 { right: calc(9 * 100% / 12); }
.m-pull-t-10 { right: calc(10 * 100% / 12); }
.m-pull-t-11 { right: calc(11 * 100% / 12); }
@media screen and (min-width: 576px) {
.m-container { width: 560px; }
.m-container-inflatable .m-col-s-10 .m-container-inflate:not([class*='m-left-']):not([class*='m-right-']) { margin-left: -10%; margin-right: -10%; }
.m-container-inflatable .m-col-s-10 .m-container-inflate.m-left-s { margin-left: -10%; }
.m-container-inflatable .m-col-s-10 .m-container-inflate.m-right-s { margin-right: -10%; }
[class*='m-col-s-'] { float: left; }
.m-left-s { padding-right: 1rem; float: left; }
.m-right-s, [class*='m-col-s-'].m-right-s { padding-left: 1rem; float: right; }
.m-center-s, [class*='m-col-s-'].m-center-s { margin-left: auto; margin-right: auto; float: none; }
.m-col-s-1 { width: calc(1 * 100% / 12); }
.m-col-s-2 { width: calc(2 * 100% / 12); }
.m-col-s-3 { width: calc(3 * 100% / 12); }
.m-col-s-4 { width: calc(4 * 100% / 12); }
.m-col-s-5 { width: calc(5 * 100% / 12); }
.m-col-s-6 { width: calc(6 * 100% / 12); }
.m-col-s-7 { width: calc(7 * 100% / 12); }
.m-col-s-8 { width: calc(8 * 100% / 12); }
.m-col-s-9 { width: calc(9 * 100% / 12); }
.m-col-s-10 { width: calc(10 * 100% / 12); }
.m-col-s-11 { width: calc(11 * 100% / 12); }
.m-col-s-12 { width: calc(12 * 100% / 12); }
.m-push-s-0 { left: calc(0 * 100% / 12); }
.m-push-s-1 { left: calc(1 * 100% / 12); }
.m-push-s-2 { left: calc(2 * 100% / 12); }
.m-push-s-3 { left: calc(3 * 100% / 12); }
.m-push-s-4 { left: calc(4 * 100% / 12); }
.m-push-s-5 { left: calc(5 * 100% / 12); }
.m-push-s-6 { left: calc(6 * 100% / 12); }
.m-push-s-7 { left: calc(7 * 100% / 12); }
.m-push-s-8 { left: calc(8 * 100% / 12); }
.m-push-s-9 { left: calc(9 * 100% / 12); }
.m-push-s-10 { left: calc(10 * 100% / 12); }
.m-push-s-11 { left: calc(11 * 100% / 12); }
.m-pull-s-0 { right: calc(0 * 100% / 12); }
.m-pull-s-1 { right: calc(1 * 100% / 12); }
.m-pull-s-2 { right: calc(2 * 100% / 12); }
.m-pull-s-3 { right: calc(3 * 100% / 12); }
.m-pull-s-4 { right: calc(4 * 100% / 12); }
.m-pull-s-5 { right: calc(5 * 100% / 12); }
.m-pull-s-6 { right: calc(6 * 100% / 12); }
.m-pull-s-7 { right: calc(7 * 100% / 12); }
.m-pull-s-8 { right: calc(8 * 100% / 12); }
.m-pull-s-9 { right: calc(9 * 100% / 12); }
.m-pull-s-10 { right: calc(10 * 100% / 12); }
.m-pull-s-11 { right: calc(11 * 100% / 12); }
.m-clearfix-t::after { display: none; }
.m-hide-s { display: none; }
.m-show-s { display: block; }
.m-col-s-none { width: auto; float: none; }
}
@media screen and (min-width: 768px) {
.m-container { width: 750px; }
.m-container-inflatable .m-col-m-10 .m-container-inflate:not([class*='m-left-']):not([class*='m-right-']) { margin-left: -10%; margin-right: -10%; }
.m-container-inflatable .m-col-m-10 .m-container-inflate.m-left-m { margin-left: -10%; }
.m-container-inflatable .m-col-m-10 .m-container-inflate.m-right-m { margin-right: -10%; }
[class*='m-col-m-'] { float: left; }
.m-left-m { padding-right: 1rem; float: left; }
.m-right-m, [class*='m-col-m-'].m-right-m { padding-left: 1rem; float: right; }
.m-center-m, [class*='m-col-m-'].m-center-m { margin-left: auto; margin-right: auto; float: none; }
.m-col-m-1 { width: calc(1 * 100% / 12); }
.m-col-m-2 { width: calc(2 * 100% / 12); }
.m-col-m-3 { width: calc(3 * 100% / 12); }
.m-col-m-4 { width: calc(4 * 100% / 12); }
.m-col-m-5 { width: calc(5 * 100% / 12); }
.m-col-m-6 { width: calc(6 * 100% / 12); }
.m-col-m-7 { width: calc(7 * 100% / 12); }
.m-col-m-8 { width: calc(8 * 100% / 12); }
.m-col-m-9 { width: calc(9 * 100% / 12); }
.m-col-m-10 { width: calc(10 * 100% / 12); }
.m-col-m-11 { width: calc(11 * 100% / 12); }
.m-col-m-12 { width: calc(12 * 100% / 12); }
.m-push-m-0 { left: calc(0 * 100% / 12); }
.m-push-m-1 { left: calc(1 * 100% / 12); }
.m-push-m-2 { left: calc(2 * 100% / 12); }
.m-push-m-3 { left: calc(3 * 100% / 12); }
.m-push-m-4 { left: calc(4 * 100% / 12); }
.m-push-m-5 { left: calc(5 * 100% / 12); }
.m-push-m-6 { left: calc(6 * 100% / 12); }
.m-push-m-7 { left: calc(7 * 100% / 12); }
.m-push-m-8 { left: calc(8 * 100% / 12); }
.m-push-m-9 { left: calc(9 * 100% / 12); }
.m-push-m-10 { left: calc(10 * 100% / 12); }
.m-push-m-11 { left: calc(11 * 100% / 12); }
.m-pull-m-0 { right: calc(0 * 100% / 12); }
.m-pull-m-1 { right: calc(1 * 100% / 12); }
.m-pull-m-2 { right: calc(2 * 100% / 12); }
.m-pull-m-3 { right: calc(3 * 100% / 12); }
.m-pull-m-4 { right: calc(4 * 100% / 12); }
.m-pull-m-5 { right: calc(5 * 100% / 12); }
.m-pull-m-6 { right: calc(6 * 100% / 12); }
.m-pull-m-7 { right: calc(7 * 100% / 12); }
.m-pull-m-8 { right: calc(8 * 100% / 12); }
.m-pull-m-9 { right: calc(9 * 100% / 12); }
.m-pull-m-10 { right: calc(10 * 100% / 12); }
.m-pull-m-11 { right: calc(11 * 100% / 12); }
.m-clearfix-s::after { display: none; }
.m-hide-m { display: none; }
.m-show-m { display: block; }
.m-col-m-none { width: auto; float: none; }
}
@media screen and (min-width: 992px) {
.m-container { width: 960px; }
.m-container-inflatable .m-col-l-10 .m-container-inflate:not([class*='m-left-']):not([class*='m-right-']) { margin-left: -10%; margin-right: -10%; }
.m-container-inflatable .m-col-l-10 .m-container-inflate.m-left-l { margin-left: -10%; }
.m-container-inflatable .m-col-l-10 .m-container-inflate.m-right-l { margin-right: -10%; }
[class*='m-col-l-'] { float: left; }
.m-left-l { padding-right: 1rem; float: left; }
.m-right-l, [class*='m-col-l-'].m-right-l { padding-left: 1rem; float: right; }
.m-center-l, [class*='m-col-l-'].m-center-l { margin-left: auto; margin-right: auto; float: none; }
.m-col-l-1 { width: calc(1 * 100% / 12); }
.m-col-l-2 { width: calc(2 * 100% / 12); }
.m-col-l-3 { width: calc(3 * 100% / 12); }
.m-col-l-4 { width: calc(4 * 100% / 12); }
.m-col-l-5 { width: calc(5 * 100% / 12); }
.m-col-l-6 { width: calc(6 * 100% / 12); }
.m-col-l-7 { width: calc(7 * 100% / 12); }
.m-col-l-8 { width: calc(8 * 100% / 12); }
.m-col-l-9 { width: calc(9 * 100% / 12); }
.m-col-l-10 { width: calc(10 * 100% / 12); }
.m-col-l-11 { width: calc(11 * 100% / 12); }
.m-col-l-12 { width: calc(12 * 100% / 12); }
.m-push-l-0 { left: calc(0 * 100% / 12); }
.m-push-l-1 { left: calc(1 * 100% / 12); }
.m-push-l-2 { left: calc(2 * 100% / 12); }
.m-push-l-3 { left: calc(3 * 100% / 12); }
.m-push-l-4 { left: calc(4 * 100% / 12); }
.m-push-l-5 { left: calc(5 * 100% / 12); }
.m-push-l-6 { left: calc(6 * 100% / 12); }
.m-push-l-7 { left: calc(7 * 100% / 12); }
.m-push-l-8 { left: calc(8 * 100% / 12); }
.m-push-l-9 { left: calc(9 * 100% / 12); }
.m-push-l-10 { left: calc(10 * 100% / 12); }
.m-push-l-11 { left: calc(11 * 100% / 12); }
.m-pull-l-0 { right: calc(0 * 100% / 12); }
.m-pull-l-1 { right: calc(1 * 100% / 12); }
.m-pull-l-2 { right: calc(2 * 100% / 12); }
.m-pull-l-3 { right: calc(3 * 100% / 12); }
.m-pull-l-4 { right: calc(4 * 100% / 12); }
.m-pull-l-5 { right: calc(5 * 100% / 12); }
.m-pull-l-6 { right: calc(6 * 100% / 12); }
.m-pull-l-7 { right: calc(7 * 100% / 12); }
.m-pull-l-8 { right: calc(8 * 100% / 12); }
.m-pull-l-9 { right: calc(9 * 100% / 12); }
.m-pull-l-10 { right: calc(10 * 100% / 12); }
.m-pull-l-11 { right: calc(11 * 100% / 12); }
.m-clearfix-m::after { display: none; }
.m-hide-l { display: none; }
.m-show-l { display: block; }
.m-col-l-none { width: auto; float: none; }
}
/*==== ../mcss/css/m-components.css ==================================================================================*/
html { font-size: var(--font-size); background-color: var(--background-color); }
body { font-family: var(--font); font-size: 1rem; line-height: var(--line-height); color: var(--color); }
h1, h2, h3, h4, h5, h6 { margin-top: 0; font-weight: var(--heading-font-weight); }
h1 { margin-bottom: 1rem; }
h2, h3, h4, h5, h6 { margin-bottom: 0.5rem; }
p, ul, ol, dl { margin-top: 0; }
ul, ol { padding-left: 2rem; }
ul ol, ul ul, ol ol, ol ul { margin-bottom: 0; }
main p { text-indent: var(--paragraph-indent); text-align: var(--paragraph-align); }
main p.m-noindent, li > p, dd > p, table.m-table td > p { text-indent: 0; text-align: left; }
blockquote {
margin-top: 0;
margin-left: 1rem;
margin-right: 1rem;
padding: 1rem;
border-left-style: solid;
border-left-width: 0.25rem;
}
hr { width: 75%; border-width: 0.0625rem; border-style: solid; }
blockquote, hr { border-color: var(--line-color); }
strong, .m-text.m-strong { font-weight: bold; }
em, .m-text.m-em { font-style: italic; }
s, .m-text.m-s { text-decoration: line-through; }
sub, sup, .m-text.m-sub, .m-text.m-sup { font-size: 0.75rem; line-height: 0; position: relative; vertical-align: baseline; }
sup, .m-text.m-sup { top: -0.35rem; }
sub, .m-text.m-sub { bottom: -0.2rem; }
abbr { cursor: help; text-decoration: underline dotted; }
a { color: var(--link-color); }
a.m-flat { text-decoration: none; }
a:hover, a:focus, a:active { color: var(--link-active-color); }
a img { border: 0; }
svg a { cursor: pointer; }
mark { padding: 0.0625rem; background-color: var(--mark-background-color); color: var(--mark-color); }
.m-link-wrap { word-break: break-all; }
pre, code {
font-family: var(--code-font), monospace, monospace;
font-size: var(--code-font-size);
color: var(--code-color);
background-color: var(--code-background-color);
}
pre.m-console, code.m-console { color: var(--console-color); background-color: var(--console-background-color); }
pre { padding: 0.5rem 1rem; border-radius: var(--border-radius); overflow-x: auto; margin-top: 0; }
pre.m-console-wrap { white-space: pre-wrap; word-break: break-all; }
code { padding: 0.125rem; }
*:focus { outline-color: var(--header-link-current-color); }
div.m-scroll { max-width: 100%; overflow-x: auto; }
.m-fullwidth { width: 100%; }
.m-spacing-150 { line-height: 1.5rem; }
.m-text-center, .m-text-center.m-noindent, table.m-table th.m-text-center, .m-text-center p { text-align: center; }
.m-text-left, .m-text-left.m-noindent, table.m-table th.m-text-left, .m-text-right p { text-align: left; }
.m-text-right, .m-text-right.m-noindent, table.m-table th.m-text-right, .m-text-right p { text-align: right; }
.m-text-top, table.m-table th.m-text-top, table.m-table td.m-text-top { vertical-align: top; }
.m-text-middle, table.m-table th.m-text-middle, table.m-table td.m-text-middle { vertical-align: middle; }
.m-text-bottom, table.m-table th.m-text-bottom, table.m-table td.m-text-bottom { vertical-align: bottom; }
.m-text.m-tiny { font-size: 50.0%; }
.m-text.m-small { font-size: 85.4%; }
.m-text.m-big { font-size: 117%; }
h1 .m-thin, h2 .m-thin, h3 .m-thin, h4 .m-thin, h5 .m-thin, h6 .m-thin { font-weight: normal; }
ul.m-unstyled, ol.m-unstyled { list-style-type: none; padding-left: 0; }
ul[class*='m-block-'], ol[class*='m-block-'] { padding-left: 0; }
ul[class*='m-block-'] li, ol[class*='m-block-'] li { display: inline; }
ul[class*='m-block-bar-'] li:not(:last-child)::after, ol[class*='m-block-bar-'] li:not(:last-child)::after { content: " | "; }
ul[class*='m-block-dot-'] li:not(:last-child)::after, ol[class*='m-block-dot-'] li:not(:last-child)::after { content: " • "; }
@media screen and (min-width: 576px) {
ul.m-block-bar-s, ol.m-block-bar-s,
ul.m-block-dot-s, ol.m-block-dot-s { padding-left: 2rem; }
ul.m-block-bar-s li, ol.m-block-bar-s li,
ul.m-block-dot-s li, ol.m-block-dot-s li { display: list-item; }
ul.m-block-bar-s li:not(:last-child)::after, ol.m-block-bar-s li:not(:last-child)::after,
ul.m-block-dot-s li:not(:last-child)::after, ol.m-block-dot-s li:not(:last-child)::after { content: ""; }
}
@media screen and (min-width: 768px) {
ul.m-block-bar-m, ol.m-block-bar-m,
ul.m-block-dot-m, ol.m-block-dot-m { padding-left: 2rem; }
ul.m-block-bar-m li, ol.m-block-bar-m li,
ul.m-block-dot-m li, ol.m-block-dot-m li { display: list-item; }
ul.m-block-bar-m li:not(:last-child)::after, ol.m-block-bar-m li:not(:last-child)::after,
ul.m-block-dot-m li:not(:last-child)::after, ol.m-block-dot-m li:not(:last-child)::after { content: ""; }
}
@media screen and (min-width: 992px) {
ul.m-block-bar-l, ol.m-block-bar-l,
ul.m-block-dot-l, ol.m-block-dot-l { padding-left: 2rem; }
ul.m-block-bar-l li, ol.m-block-bar-l li,
ul.m-block-dot-l li, ol.m-block-dot-l li { display: list-item; }
ul.m-block-bar-l li:not(:last-child)::after, ol.m-block-bar-l li:not(:last-child)::after,
ul.m-block-dot-l li:not(:last-child)::after, ol.m-block-dot-l li:not(:last-child)::after { content: ""; }
}
p.m-poem { text-indent: 0; text-align: left; margin-left: var(--paragraph-indent); }
p.m-transition { color: var(--line-color); text-indent: 0; text-align: center; font-size: 2rem; }
dl.m-diary { margin-bottom: 1.25rem; }
dl.m-diary:last-child { margin-bottom: 0.25rem; }
dl.m-diary dt { font-weight: bold; width: 6rem; float: left; clear: both; padding-top: 0.25rem; }
dl.m-diary dd { padding-top: 0.25rem; padding-left: 6rem; margin-left: 0; }
a.m-footnote, dl.m-footnote dd span.m-footnote { top: -0.35rem; font-size: 0.75rem; line-height: 0; position: relative; vertical-align: baseline; }
a.m-footnote, dl.m-footnote dd span.m-footnote a { text-decoration: none; }
a.m-footnote::before { content: '['; }
a.m-footnote::after { content: ']'; }
dl.m-footnote dt { width: 1.5rem; float: left; clear: both; }
dl.m-footnote dd { margin-left: 1.5rem; }
dl.m-footnote { font-size: 85.4%; }
dl.m-footnote dd span.m-footnote a { font-weight: bold; font-style: italic; }
.m-note { border-radius: var(--border-radius); padding: 1rem; }
.m-frame {
background-color: var(--background-color);
border-style: solid;
border-width: 0.125rem;
border-radius: var(--border-radius);
border-color: var(--line-color);
padding: 0.875rem;
}
.m-block {
border-style: solid;
border-width: 0.0625rem;
border-left-width: 0.25rem;
border-radius: var(--border-radius);
border-color: var(--line-color);
padding: 0.9375rem 0.9375rem 0.9375rem 0.75rem;
}
.m-block.m-badge::after { content: ' '; display: block; clear: both; }
.m-block.m-badge h3 { margin-left: 5rem; }
.m-block.m-badge p { margin-left: 5rem; text-indent: 0; }
.m-block.m-badge img { width: 4rem; height: 4rem; border-radius: 2rem; float: left; }
div.m-button { text-align: center; }
div.m-button a {
display: inline-block;
border-radius: var(--border-radius);
padding-top: 0.75rem;
padding-bottom: 0.75rem;
padding-left: 1.5rem;
padding-right: 1.5rem;
text-decoration: none;
font-size: 1.17rem;
}
div.m-button.m-fullwidth a { display: block; padding-left: 0.5rem; padding-right: 0.5rem; }
div.m-button a .m-big:first-child { font-size: 1.37rem; font-weight: bold; }
div.m-button a .m-small:last-child { font-size: 0.854rem; }
.m-label {
border-radius: var(--border-radius);
font-size: 75%;
font-weight: normal;
padding: 0.125rem 0.25rem;
vertical-align: 7.5%;
}
.m-label.m-flat {
border-width: 0.0625rem;
border-style: solid;
border-color: var(--dim-color);
padding: 0.0625rem 0.1875rem;
}
table.m-table { border-collapse: collapse; margin-left: auto; margin-right: auto; }
table.m-table.m-big { margin-top: 1.75rem; }
div.m-scroll > table.m-table:last-child { margin-bottom: 0.0625rem; }
table.m-table:not(.m-flat) tbody tr:hover { background-color: var(--line-color); }
table.m-table th, table.m-table td {
vertical-align: top;
border-style: solid;
border-top-width: 0.0625rem;
border-left-width: 0;
border-right-width: 0;
border-bottom-width: 0;
border-color: var(--line-color);
}
table.m-table caption { padding-bottom: 0.5rem; }
table.m-table thead tr:first-child th, table.m-table thead tr:first-child td { border-top-width: 0.125rem; }
table.m-table thead th, table.m-table thead td { border-bottom-width: 0.125rem; vertical-align: bottom; }
table.m-table tfoot th, table.m-table tfoot td { border-top-width: 0.125rem; }
table.m-table th, table.m-table td { padding: 0.5rem; }
table.m-table.m-big th, table.m-table.m-big td { padding: 0.75rem 1rem; }
table.m-table th { text-align: left; }
table.m-table th.m-thin { font-weight: normal; }
table.m-table td.m-default, table.m-table th.m-default,
table.m-table td.m-primary, table.m-table th.m-primary,
table.m-table td.m-success, table.m-table th.m-success,
table.m-table td.m-warning, table.m-table th.m-warning,
table.m-table td.m-danger, table.m-table th.m-danger,
table.m-table td.m-info, table.m-table th.m-info,
table.m-table td.m-dim, table.m-table th.m-dim { padding-left: 0.4375rem; padding-right: 0.4375rem; border-left-width: 0.0625rem; }
table.m-table.m-big td.m-default, table.m-table.m-big th.m-default,
table.m-table.m-big td.m-primary, table.m-table.m-big th.m-primary,
table.m-table.m-big td.m-success, table.m-table.m-big th.m-success,
table.m-table.m-big td.m-warning, table.m-table.m-big th.m-warning,
table.m-table.m-big td.m-danger, table.m-table.m-big th.m-danger,
table.m-table.m-big td.m-info, table.m-table.m-big th.m-info,
table.m-table.m-big td.m-dim, table.m-table.m-big th.m-dim { padding-left: 0.9375rem; padding-right: 0.9375rem; border-left-width: 0.0625rem; }
table.m-table tr.m-default td, table.m-table td.m-default,
table.m-table tr.m-default th, table.m-table th.m-default,
table.m-table tr.m-primary td, table.m-table td.m-primary,
table.m-table tr.m-primary th, table.m-table th.m-primary,
table.m-table tr.m-success td, table.m-table td.m-success,
table.m-table tr.m-success th, table.m-table th.m-success,
table.m-table tr.m-warning td, table.m-table td.m-warning,
table.m-table tr.m-warning th, table.m-table th.m-warning,
table.m-table tr.m-danger td, table.m-table td.m-danger,
table.m-table tr.m-danger th, table.m-table th.m-danger,
table.m-table tr.m-info td, table.m-table td.m-info,
table.m-table tr.m-info th, table.m-table th.m-info,
table.m-table tr.m-dim td, table.m-table td.m-dim,
table.m-table tr.m-dim th, table.m-table th.m-dim { border-color: var(--background-color); }
.m-note pre, .m-note code,
table.m-table tr.m-default pre, table.m-table tr.m-default code,
table.m-table td.m-default pre, table.m-table td.m-default code,
table.m-table th.m-default pre, table.m-table th.m-default code,
table.m-table tr.m-primary pre, table.m-table tr.m-primary code,
table.m-table td.m-primary pre, table.m-table td.m-primary code,
table.m-table th.m-primary pre, table.m-table th.m-primary code,
table.m-table tr.m-success pre, table.m-table tr.m-success code,
table.m-table td.m-success pre, table.m-table td.m-success code,
table.m-table th.m-success pre, table.m-table th.m-success code,
table.m-table tr.m-warning pre, table.m-table tr.m-warning code,
table.m-table td.m-warning pre, table.m-table td.m-warning code,
table.m-table th.m-warning pre, table.m-table th.m-warning code,
table.m-table tr.m-danger pre, table.m-table tr.m-danger code,
table.m-table td.m-danger pre, table.m-table td.m-danger code,
table.m-table th.m-danger pre, table.m-table th.m-danger code,
table.m-table tr.m-info pre, table.m-table tr.m-info code,
table.m-table td.m-info pre, table.m-table td.m-info code,
table.m-table th.m-info pre, table.m-table th.m-info code,
table.m-table tr.m-dim pre, table.m-table tr.m-dim code,
table.m-table td.m-dim pre, table.m-table td.m-dim code,
table.m-table th.m-dim pre, table.m-table th.m-dim code { background-color: var(--code-note-background-color); }
img.m-image, svg.m-image, video.m-image { display: block; margin-left: auto; margin-right: auto; }
div.m-image { text-align: center; }
img.m-image, svg.m-image, video.m-image,
div.m-image img, div.m-image svg, div.m-image video { max-width: 100%; border-radius: var(--border-radius); }
div.m-image.m-fullwidth img,
div.m-image.m-fullwidth svg,
div.m-image.m-fullwidth video { width: 100%; }
img.m-image.m-badge, div.m-image.m-badge img { border-radius: 50%; }
figure.m-figure {
max-width: 100%;
margin-top: 0;
margin-left: auto;
margin-right: auto;
position: relative;
display: table;
}
figure.m-figure::before {
position: absolute;
content: ' ';
top: 0;
bottom: 0;
left: 0;
right: 0;
z-index: -1;
border-style: solid;
border-width: 0.125rem;
border-radius: var(--border-radius);
border-color: var(--line-color);
}
figure.m-figure.m-flat::before { border-color: transparent; }
figure.m-figure > * { margin-left: 1rem; margin-right: 1rem; display: table-caption; caption-side: bottom; }
figure.m-figure > *:first-child { display: inline; }
figure.m-figure > *:last-child { margin-bottom: 1rem !important; }
figure.m-figure img,
figure.m-figure svg,
figure.m-figure video {
position: relative;
margin-left: 0;
margin-right: 0;
margin-bottom: 0;
border-top-left-radius: var(--border-radius);
border-top-right-radius: var(--border-radius);
max-width: 100%;
}
figure.m-figure.m-flat img,
figure.m-figure.m-flat svg,
figure.m-figure.m-flat video { border-bottom-left-radius: var(--border-radius); border-bottom-right-radius: var(--border-radius); }
figure.m-figure a img,
figure.m-figure a svg,
figure.m-figure a video { margin-left: -1rem; margin-right: -1rem; }
figure.m-figure.m-fullwidth, figure.m-figure.m-fullwidth > * { display: block; }
figure.m-figure.m-fullwidth > *:first-child { display: inline; }
figure.m-figure.m-fullwidth img,
figure.m-figure.m-fullwidth svg,
figure.m-figure.m-fullwidth video { width: 100%; }
figure.m-figure.m-fullwidth::after { content: ' '; display: block; margin-top: 1rem; height: 1px; }
.m-code-figure, .m-console-figure { margin-top: 0; margin-left: 0; margin-right: 0; position: relative; padding: 1rem; }
.m-code-figure::before, .m-console-figure::before {
position: absolute;
content: ' ';
top: 0;
bottom: 0;
left: 0;
right: 0;
z-index: -1;
border-style: solid;
border-width: 0.125rem;
border-radius: var(--border-radius);
}
.m-code-figure::before { border-color: var(--code-background-color); }
.m-console-figure::before { border-color: var(--console-background-color); }
.m-code-figure.m-flat::before, .m-console-figure.m-flat::before { border-color: transparent; }
.m-code-figure > pre:first-child, .m-console-figure > pre:first-child {
position: relative;
margin: -1rem -1rem 1rem -1rem;
border-bottom-left-radius: 0;
border-bottom-right-radius: 0;
}
.m-code-figure > pre.m-nopad, .m-console-figure > pre.m-nopad {
margin-left: -0.875rem;
margin-right: -0.875rem;
margin-top: -1rem;
margin-bottom: -0.875rem;
padding-left: 0.875rem;
}
figure.m-figure figcaption, .m-code-figure figcaption, .m-console-figure figcaption {
margin-top: 0.5rem;
margin-bottom: 0.5rem;
font-weight: var(--heading-font-weight);
font-size: 1.17rem;
}
figure.m-figure figcaption a, .m-code-figure figcaption a, .m-console-figure figcaption a { text-decoration: var(--link-decoration-heading); }
figure.m-figure figcaption .m-figure-description { margin-top: 0.5rem; font-weight: normal; font-size: 1rem; }
figure.m-figure figcaption .m-figure-description a { text-decoration: var(--link-decoration); }
.m-imagegrid > div { background-color: var(--background-color); }
.m-imagegrid > div > figure { display: block; float: left; position: relative; margin: 0; }
.m-imagegrid > div > figure > div,
.m-imagegrid > div > figure > figcaption,
.m-imagegrid > div > figure > a > div,
.m-imagegrid > div > figure > a > figcaption {
position: absolute;
top: 0;
left: 0;
width: 100%;
height: 100%;
border-color: var(--background-color);
border-style: solid;
border-width: 0.25rem;
padding: 0.5rem;
}
.m-imagegrid > div > figure:first-child > div,
.m-imagegrid > div > figure:first-child > figcaption,
.m-imagegrid > div > figure:first-child > a > div,
.m-imagegrid > div > figure:first-child > a > figcaption { border-left-width: 0; }
.m-imagegrid > div > figure:last-child > div,
.m-imagegrid > div > figure:last-child > figcaption,
.m-imagegrid > div > figure:last-child > a > div,
.m-imagegrid > div > figure:last-child > a > figcaption { border-right-width: 0; }
.m-imagegrid > div > figure > figcaption,
.m-imagegrid > div > figure > a > figcaption {
color: transparent;
overflow: hidden;
text-overflow: ellipsis;
white-space: nowrap;
font-size: 0.75rem;
}
.m-imagegrid > div > figure > div::before,
.m-imagegrid > div > figure > figcaption::before,
.m-imagegrid > div > figure > a > div::before,
.m-imagegrid > div > figure > a > figcaption::before { content: ''; display: inline-block; height: 100%; vertical-align: bottom; width: 0; }
.m-imagegrid > div > figure:hover > figcaption,
.m-imagegrid > div > figure:hover > a > figcaption {
background: linear-gradient(transparent 0%, transparent 75%, rgba(0, 0, 0, 0.85) 100%);
color: #ffffff;
}
.m-imagegrid > div > figure > img,
.m-imagegrid > div > figure > a > img { width: 100%; height: 100%; }
.m-imagegrid > div::after { display: block; content: ' '; clear: both; }
@media screen and (max-width: 767px) {
.m-imagegrid > div > figure { float: none; width: 100% !important; }
.m-imagegrid > div > figure > div,
.m-imagegrid > div > figure > figcaption,
.m-imagegrid > div > figure > a > div,
.m-imagegrid > div > figure > a > figcaption { border-left-width: 0; border-right-width: 0; }
}
.m-container-inflatable > .m-row > [class*='m-col-'] > .m-note,
.m-container-inflatable > .m-row > [class*='m-col-'] > .m-frame,
.m-container-inflatable > .m-row > [class*='m-col-'] > .m-block,
.m-container-inflatable > .m-row > [class*='m-col-'] > .m-imagegrid,
.m-container-inflatable > .m-row > [class*='m-col-'] > pre,
.m-container-inflatable > .m-row > [class*='m-col-'] > .m-code-figure,
.m-container-inflatable > .m-row > [class*='m-col-'] > .m-console-figure,
.m-container-inflatable > .m-row > [class*='m-col-'] section > .m-note,
.m-container-inflatable > .m-row > [class*='m-col-'] section > .m-frame,
.m-container-inflatable > .m-row > [class*='m-col-'] section > .m-block,
.m-container-inflatable > .m-row > [class*='m-col-'] section > .m-imagegrid,
.m-container-inflatable > .m-row > [class*='m-col-'] section > pre,
.m-container-inflatable > .m-row > [class*='m-col-'] section > .m-code-figure,
.m-container-inflatable > .m-row > [class*='m-col-'] section > .m-console-figure,
.m-container-inflatable [class*='m-center-'] > .m-note,
.m-container-inflatable [class*='m-center-'] > .m-frame,
.m-container-inflatable [class*='m-center-'] > .m-block,
.m-container-inflatable [class*='m-center-'] > .m-imagegrid,
.m-container-inflatable [class*='m-center-'] > pre,
.m-container-inflatable [class*='m-center-'] > .m-code-figure,
.m-container-inflatable [class*='m-center-'] > .m-console-figure,
.m-container-inflatable [class*='m-left-'] > .m-note,
.m-container-inflatable [class*='m-left-'] > .m-frame,
.m-container-inflatable [class*='m-left-'] > .m-block,
.m-container-inflatable [class*='m-left-'] > .m-imagegrid,
.m-container-inflatable [class*='m-left-'] > pre,
.m-container-inflatable [class*='m-left-'] > .m-code-figure,
.m-container-inflatable [class*='m-left-'] > .m-console-figure,
.m-container-inflatable [class*='m-right-'] > .m-note,
.m-container-inflatable [class*='m-right-'] > .m-frame,
.m-container-inflatable [class*='m-right-'] > .m-block,
.m-container-inflatable [class*='m-right-'] > .m-imagegrid,
.m-container-inflatable [class*='m-right-'] > pre,
.m-container-inflatable [class*='m-right-'] > .m-code-figure,
.m-container-inflatable [class*='m-right-'] > .m-console-figure,
.m-container-inflatable .m-container-inflate > .m-note,
.m-container-inflatable .m-container-inflate > .m-frame,
.m-container-inflatable .m-container-inflate > .m-block,
.m-container-inflatable .m-container-inflate > .m-imagegrid,
.m-container-inflatable .m-container-inflate > pre,
.m-container-inflatable .m-container-inflate > .m-code-figure,
.m-container-inflatable .m-container-inflate > .m-console-figure { margin-left: -1rem; margin-right: -1rem; }
@media screen and (min-width: 576px) {
.m-container-inflatable .m-center-s > .m-note,
.m-container-inflatable .m-center-s > .m-frame,
.m-container-inflatable .m-center-s > .m-block,
.m-container-inflatable .m-center-s > .m-imagegrid,
.m-container-inflatable .m-center-s > pre,
.m-container-inflatable .m-center-s > .m-code-figure,
.m-container-inflatable .m-center-s > .m-console-figure { margin-left: -1rem; margin-right: -1rem; }
.m-container-inflatable .m-left-s > .m-note,
.m-container-inflatable .m-left-s > .m-frame,
.m-container-inflatable .m-left-s > .m-block,
.m-container-inflatable .m-left-s > .m-imagegrid,
.m-container-inflatable .m-left-s > pre,
.m-container-inflatable .m-left-s > .m-code-figure,
.m-container-inflatable .m-left-s > .m-console-figure { margin-left: -1rem; margin-right: 0; }
.m-container-inflatable .m-right-s > .m-note,
.m-container-inflatable .m-right-s > .m-frame,
.m-container-inflatable .m-right-s > .m-block,
.m-container-inflatable .m-right-s > .m-imagegrid,
.m-container-inflatable .m-right-s > pre,
.m-container-inflatable .m-right-s > .m-code-figure,
.m-container-inflatable .m-right-s > .m-console-figure { margin-left: 0; margin-right: -1rem; }
.m-container-inflatable > .m-row > .m-col-s-10 > .m-imagegrid.m-container-inflate,
.m-container-inflatable > .m-row > .m-col-s-10 section > .m-imagegrid.m-container-inflate { margin-left: -10%; margin-right: -10%; }
}
@media screen and (min-width: 768px) {
.m-container-inflatable .m-center-m > .m-note,
.m-container-inflatable .m-center-m > .m-frame,
.m-container-inflatable .m-center-m > .m-block,
.m-container-inflatable .m-center-m > .m-imagegrid,
.m-container-inflatable .m-center-m > pre,
.m-container-inflatable .m-center-m > .m-code-figure,
.m-container-inflatable .m-center-m > .m-console-figure { margin-left: -1rem; margin-right: -1rem; }
.m-container-inflatable .m-left-m > .m-note,
.m-container-inflatable .m-left-m > .m-frame,
.m-container-inflatable .m-left-m > .m-block,
.m-container-inflatable .m-left-m > .m-imagegrid,
.m-container-inflatable .m-left-m > pre,
.m-container-inflatable .m-left-m > .m-code-figure,
.m-container-inflatable .m-left-m > .m-console-figure { margin-left: -1rem; margin-right: 0; }
.m-container-inflatable .m-right-m > .m-note,
.m-container-inflatable .m-right-m > .m-frame,
.m-container-inflatable .m-right-m > .m-block,
.m-container-inflatable .m-right-m > .m-imagegrid,
.m-container-inflatable .m-right-m > pre,
.m-container-inflatable .m-right-m > .m-code-figure,
.m-container-inflatable .m-right-m > .m-console-figure { margin-left: 0; margin-right: -1rem; }
.m-container-inflatable > .m-row > .m-col-m-10 > .m-imagegrid.m-container-inflate,
.m-container-inflatable > .m-row > .m-col-m-10 section > .m-imagegrid.m-container-inflate { margin-left: -10%; margin-right: -10%; }
}
@media screen and (min-width: 992px) {
.m-container-inflatable .m-center-l > .m-note,
.m-container-inflatable .m-center-l > .m-frame,
.m-container-inflatable .m-center-l > .m-block,
.m-container-inflatable .m-center-l > .m-imagegrid,
.m-container-inflatable .m-center-l > pre,
.m-container-inflatable .m-center-l > .m-code-figure,
.m-container-inflatable .m-center-l > .m-console-figure { margin-left: -1rem; margin-right: -1rem; }
.m-container-inflatable .m-left-l > .m-note,
.m-container-inflatable .m-left-l > .m-frame,
.m-container-inflatable .m-left-l > .m-block,
.m-container-inflatable .m-left-l > .m-imagegrid,
.m-container-inflatable .m-left-l > pre,
.m-container-inflatable .m-left-l > .m-code-figure,
.m-container-inflatable .m-left-l > .m-console-figure { margin-left: -1rem; margin-right: 0; }
.m-container-inflatable .m-right-l > .m-note,
.m-container-inflatable .m-right-l > .m-frame,
.m-container-inflatable .m-right-l > .m-block,
.m-container-inflatable .m-right-l > .m-imagegrid,
.m-container-inflatable .m-right-l > pre,
.m-container-inflatable .m-right-l > .m-code-figure,
.m-container-inflatable .m-right-l > .m-console-figure { margin-left: 0; margin-right: -1rem; }
.m-container-inflatable > .m-row > .m-col-l-10 > .m-imagegrid.m-container-inflate,
.m-container-inflatable > .m-row > .m-col-l-10 section > .m-imagegrid.m-container-inflate { margin-left: -10%; margin-right: -10%; }
}
pre.m-code span.hll { margin-left: -1.0rem; margin-right: -1.0rem; padding-left: 1.0rem; }
.m-code.m-inverted > span, .m-console.m-inverted > span { opacity: 0.3333; }
.m-code.m-inverted > span.hll, .m-console.m-inverted > span.hll { opacity: 1; background-color: transparent; border-color: transparent; }
.m-code.m-inverted { color: var(--code-inverted-color); }
.m-console.m-inverted { color: var(--console-inverted-color); }
.m-code.m-inverted > span.hll { color: var(--code-color); }
.m-cosole.m-inverted > span.hll { color: var(--console-color); }
.m-code-color {
display: inline-block;
width: 0.75rem;
height: 0.75rem;
vertical-align: -0.05rem;
margin-left: 0.2rem;
margin-right: 0.1rem;
border-radius: 0.1rem;
}
div.m-math { overflow-x: auto; overflow-y: hidden; }
div.m-math svg { margin-left: auto; margin-right: auto; display: block; }
div.m-button a svg.m-math { fill: var(--button-background-color); }
div.m-button.m-flat a svg.m-math { fill: var(--color); }
div.m-button.m-flat a:hover svg.m-math, div.m-button.m-default a:focus svg.m-math,
div.m-button.m-default a:active svg.m-math { fill: var(--link-active-color); }
.m-graph { font-size: var(--font-size); }
div.m-plot svg, div.m-graph svg { max-width: 100%; margin-left: auto; margin-right: auto; display: block; }
div.m-plot .m-background { fill: var(--plot-background-color); }
div.m-plot svg .m-label { font-size: 11px; }
div.m-plot svg .m-title { font-size: 13px; }
div.m-plot svg .m-label, div.m-plot svg .m-title { fill: var(--color); }
div.m-plot svg .m-line { stroke: var(--color); stroke-width: 0.8; }
div.m-plot svg .m-error { stroke: var(--plot-error-color); stroke-width: 1.5; }
div.m-plot svg .m-label.m-dim { fill: var(--dim-color); }
.m-graph g.m-edge path, .m-graph g.m-cluster polygon,
.m-graph g.m-node.m-flat ellipse,
.m-graph g.m-node.m-flat polygon { fill: none; }
.m-graph g.m-node:not(.m-flat) text { fill: var(--button-background-color); }
figure.m-figure > svg.m-math:first-child,
figure.m-figure > svg.m-graph:first-child { padding: 1rem; box-sizing: content-box; }
figure.m-figure:not(.m-flat) > svg.m-math:first-child,
figure.m-figure:not(.m-flat) > svg.m-graph:first-child { background-color: var(--line-color); }
.m-block.m-default { border-left-color: var(--line-color); }
.m-block.m-default h3, .m-block.m-default h4, .m-block.m-default h5, .m-block.m-default h6,
.m-text.m-default, .m-label.m-flat.m-default { color: var(--default-color); }
.m-block.m-default h3 a, .m-block.m-default h4 a, .m-block.m-default h5 a, .m-block.m-default h6 a { color: var(--link-color); }
.m-block.m-primary { border-left-color: var(--primary-color); }
.m-block.m-primary h3, .m-block.m-primary h4, .m-block.m-primary h5, .m-block.m-primary h6,
.m-block.m-primary h3 a, .m-block.m-primary h4 a, .m-block.m-primary h5 a, .m-block.m-primary h6 a,
.m-text.m-primary, .m-label.m-flat.m-primary { color: var(--primary-color); }
.m-block.m-success { border-left-color: var(--success-color); }
.m-block.m-success h3, .m-block.m-success h4, .m-block.m-success h5, .m-block.m-success h6,
.m-block.m-success h3 a, .m-block.m-success h4 a, .m-block.m-success h5 a, .m-block.m-success h6 a,
.m-text.m-success, .m-label.m-flat.m-success { color: var(--success-color); }
.m-block.m-warning { border-left-color: var(--warning-color); }
.m-block.m-warning h3, .m-block.m-warning h4, .m-block.m-warning h5, .m-block.m-warning h6,
.m-block.m-warning h3 a, .m-block.m-warning h4 a, .m-block.m-warning h5 a, .m-block.m-warning h6 a,
.m-text.m-warning, .m-label.m-flat.m-warning { color: var(--warning-color); }
.m-block.m-danger { border-left-color: var(--danger-color); }
.m-block.m-danger h3, .m-block.m-danger h4, .m-block.m-danger h5, .m-block.m-danger h6,
.m-block.m-danger h3 a, .m-block.m-danger h4 a, .m-block.m-danger h5 a, .m-block.m-danger h6 a,
.m-text.m-danger, .m-label.m-flat.m-danger { color: var(--danger-color); }
.m-block.m-info { border-left-color: var(--info-color); }
.m-block.m-info h3, .m-block.m-info h4, .m-block.m-info h5, .m-block.m-info h6,
.m-block.m-info h3 a, .m-block.m-info h4 a, .m-block.m-info h5 a, .m-block.m-info h6 a,
.m-text.m-info, .m-label.m-flat.m-info { color: var(--info-color); }
.m-block.m-dim { border-left-color: var(--dim-color); }
.m-block.m-dim, .m-text.m-dim, .m-label.m-flat.m-dim { color: var(--dim-color); }
.m-block.m-dim a, .m-text.m-dim a { color: var(--dim-link-color); }
.m-block.m-dim a:hover, .m-block.m-dim a:focus, .m-block.m-dim a:active,
.m-text.m-dim a:hover, .m-text.m-dim a:focus, .m-text.m-dim a:active { color: var(--dim-link-active-color); }
.m-block.m-flat { border-color: transparent; }
.m-block.m-flat h3, .m-block.m-flat h4, .m-block.m-flat h5, .m-block.m-flat h6 { color: var(--default-color); }
.m-block.m-default h3 a:hover, .m-block.m-default h3 a:focus, .m-block.m-default h3 a:active,
.m-block.m-default h4 a:hover, .m-block.m-default h4 a:focus, .m-block.m-default h4 a:active,
.m-block.m-default h5 a:hover, .m-block.m-default h5 a:focus, .m-block.m-default h5 a:active,
.m-block.m-default h6 a:hover, .m-block.m-default h6 a:focus, .m-block.m-default h6 a:active { color: var(--default-link-active-color); }
.m-block.m-primary h3 a:hover, .m-block.m-primary h3 a:focus, .m-block.m-primary h3 a:active,
.m-block.m-primary h4 a:hover, .m-block.m-primary h4 a:focus, .m-block.m-primary h4 a:active,
.m-block.m-primary h5 a:hover, .m-block.m-primary h5 a:focus, .m-block.m-primary h5 a:active,
.m-block.m-primary h6 a:hover, .m-block.m-primary h6 a:focus, .m-block.m-primary h6 a:active { color: var(--primary-link-active-color); }
.m-block.m-success h3 a:hover, .m-block.m-success h3 a:focus, .m-block.m-success h3 a:active,
.m-block.m-success h4 a:hover, .m-block.m-success h4 a:focus, .m-block.m-success h4 a:active,
.m-block.m-success h5 a:hover, .m-block.m-success h5 a:focus, .m-block.m-success h5 a:active,
.m-block.m-success h6 a:hover, .m-block.m-success h6 a:focus, .m-block.m-success h6 a:active { color: var(--success-link-active-color); }
.m-block.m-warning h3 a:hover, .m-block.m-warning h3 a:focus, .m-block.m-warning h3 a:active,
.m-block.m-warning h4 a:hover, .m-block.m-warning h4 a:focus, .m-block.m-warning h4 a:active,
.m-block.m-warning h5 a:hover, .m-block.m-warning h5 a:focus, .m-block.m-warning h5 a:active,
.m-block.m-warning h6 a:hover, .m-block.m-warning h6 a:focus, .m-block.m-warning h6 a:active { color: var(--warning-link-active-color); }
.m-block.m-danger h3 a:hover, .m-block.m-danger h3 a:focus, .m-block.m-danger h3 a:active,
.m-block.m-danger h4 a:hover, .m-block.m-danger h4 a:focus, .m-block.m-danger h4 a:active,
.m-block.m-danger h5 a:hover, .m-block.m-danger h5 a:focus, .m-block.m-danger h5 a:active,
.m-block.m-danger h6 a:hover, .m-block.m-danger h6 a:focus, .m-block.m-danger h6 a:active { color: var(--danger-link-active-color); }
.m-block.m-info h3 a:hover, .m-block.m-info h3 a:focus, .m-block.m-info h3 a:active,
.m-block.m-info h4 a:hover, .m-block.m-info h4 a:focus, .m-block.m-info h4 a:active,
.m-block.m-info h5 a:hover, .m-block.m-info h5 a:focus, .m-block.m-info h5 a:active,
.m-block.m-info h6 a:hover, .m-block.m-info h6 a:focus, .m-block.m-info h6 a:active { color: var(--info-link-active-color); }
div.m-button a, .m-label { color: var(--button-background-color); }
div.m-button.m-flat a { color: var(--color); }
div.m-button.m-flat a:hover, div.m-button.m-default a:focus, div.m-button.m-default a:active { color: var(--link-active-color); }
div.m-button.m-default a, .m-label:not(.m-flat).m-default { background-color: var(--default-color); }
div.m-button.m-primary a, .m-label:not(.m-flat).m-primary { background-color: var(--primary-color); }
div.m-button.m-success a, .m-label:not(.m-flat).m-success { background-color: var(--success-color); }
div.m-button.m-warning a, .m-label:not(.m-flat).m-warning { background-color: var(--warning-color); }
div.m-button.m-danger a, .m-label:not(.m-flat).m-danger { background-color: var(--danger-color); }
div.m-button.m-info a, .m-label:not(.m-flat).m-info { background-color: var(--info-color); }
div.m-button.m-dim a, .m-label:not(.m-flat).m-dim { background-color: var(--dim-color); }
div.m-button.m-default a:hover, div.m-button.m-default a:focus, div.m-button.m-default a:active { background-color: var(--default-link-active-color); }
div.m-button.m-primary a:hover, div.m-button.m-primary a:focus, div.m-button.m-primary a:active { background-color: var(--primary-link-active-color); }
div.m-button.m-success a:hover, div.m-button.m-success a:focus, div.m-button.m-success a:active { background-color: var(--success-link-active-color); }
div.m-button.m-warning a:hover, div.m-button.m-warning a:focus, div.m-button.m-warning a:active { background-color: var(--warning-link-active-color); }
div.m-button.m-danger a:hover, div.m-button.m-danger a:focus, div.m-button.m-danger a:active { background-color: var(--danger-link-active-color); }
div.m-button.m-info a:hover, div.m-button.m-info a:focus, div.m-button.m-info a:active { background-color: var(--info-link-active-color); }
div.m-button.m-dim a:hover, div.m-button.m-dim a:focus, div.m-button.m-dim a:active { background-color: var(--dim-button-active-color); }
.m-note.m-default { background-color: var(--default-filled-background-color); }
.m-note.m-default,
table.m-table tr.m-default td, table.m-table td.m-default,
table.m-table tr.m-default th, table.m-table th.m-default { color: var(--default-filled-color); }
.m-note.m-default a:hover,
table.m-table tr.m-default td a:hover, table.m-table td.m-default a:hover,
table.m-table tr.m-default th a:hover, table.m-table th.m-default a:hover,
.m-note.m-default a:focus,
table.m-table tr.m-default td a:focus, table.m-table td.m-default a:focus,
table.m-table tr.m-default th a:focus, table.m-table th.m-default a:focus,
.m-note.m-default a:active,
table.m-table tr.m-default td a:active, table.m-table td.m-default a:active,
table.m-table tr.m-default th a:active, table.m-table th.m-default a:active { color: var(--default-filled-link-active-color); }
.m-note.m-primary a,
table.m-table tr.m-primary td a, table.m-table td.m-primary a,
table.m-table tr.m-primary th a, table.m-table th.m-primary a { color: var(--default-filled-link-color); }
.m-note.m-primary,
table.m-table tr.m-primary td, table.m-table td.m-primary,
table.m-table tr.m-primary th, table.m-table th.m-primary { background-color: var(--primary-filled-background-color); color: var(--primary-filled-color); }
.m-note.m-primary a,
table.m-table tr.m-primary td a, table.m-table td.m-primary a,
table.m-table tr.m-primary th a, table.m-table th.m-primary a { color: var(--primary-filled-link-color); }
.m-note.m-primary a:hover,
table.m-table tr.m-primary td a:hover, table.m-table td.m-primary a:hover,
table.m-table tr.m-primary th a:hover, table.m-table th.m-primary a:hover,
.m-note.m-primary a:focus,
table.m-table tr.m-primary td a:focus, table.m-table td.m-primary a:focus,
table.m-table tr.m-primary th a:focus, table.m-table th.m-primary a:focus,
.m-note.m-primary a:active,
table.m-table tr.m-primary td a:active, table.m-table td.m-primary a:active,
table.m-table tr.m-primary th a:active, table.m-table th.m-primary a:active { color: var(--primary-filled-link-active-color); }
.m-note.m-success,
table.m-table tr.m-success td, table.m-table td.m-success,
table.m-table tr.m-success th, table.m-table th.m-success { background-color: var(--success-filled-background-color); color: var(--success-filled-color); }
.m-note.m-success a,
table.m-table tr.m-success td a, table.m-table td.m-success a,
table.m-table tr.m-success th a, table.m-table th.m-success a { color: var(--success-filled-link-color); }
.m-note.m-success a:hover,
table.m-table tr.m-success td a:hover, table.m-table td.m-success a:hover,
table.m-table tr.m-success th a:hover, table.m-table th.m-success a:hover,
.m-note.m-success a:focus,
table.m-table tr.m-success td a:focus, table.m-table td.m-success a:focus,
table.m-table tr.m-success th a:focus, table.m-table th.m-success a:focus,
.m-note.m-success a:active,
table.m-table tr.m-success td a:active, table.m-table td.m-success a:active,
table.m-table tr.m-success th a:active, table.m-table th.m-success a:active { color: var(--success-filled-link-active-color); }
.m-note.m-warning, table.m-table tr.m-warning td, table.m-table td.m-warning,
table.m-table tr.m-warning th, table.m-table th.m-warning { background-color: var(--warning-filled-background-color); color: var(--warning-filled-color); }
.m-note.m-warning a, table.m-table tr.m-warning td a, table.m-table td.m-warning a,
table.m-table tr.m-warning th a, table.m-table th.m-warning a { color: var(--warning-filled-link-color); }
.m-note.m-warning a:hover,
table.m-table tr.m-warning td a:hover, table.m-table td.m-warning a:hover,
table.m-table tr.m-warning th a:hover, table.m-table th.m-warning a:hover,
.m-note.m-warning a:focus,
table.m-table tr.m-warning td a:focus, table.m-table td.m-warning a:focus,
table.m-table tr.m-warning th a:focus, table.m-table th.m-warning a:focus,
.m-note.m-warning a:active,
table.m-table tr.m-warning td a:active, table.m-table td.m-warning a:active,
table.m-table tr.m-warning th a:active, table.m-table th.m-warning a:active { color: var(--warning-filled-link-active-color); }
.m-note.m-danger,
table.m-table tr.m-danger td, table.m-table td.m-danger,
table.m-table tr.m-danger th, table.m-table th.m-danger { background-color: var(--danger-filled-background-color); color: var(--danger-filled-color); }
.m-note.m-danger a,
table.m-table tr.m-danger td a, table.m-table td.m-danger a,
table.m-table tr.m-danger th a, table.m-table th.m-danger a { color: var(--danger-filled-link-color); }
.m-note.m-danger a:hover,
table.m-table tr.m-danger td a:hover, table.m-table td.m-danger a:hover,
table.m-table tr.m-danger th a:hover, table.m-table th.m-danger a:hover,
.m-note.m-danger a:focus,
table.m-table tr.m-danger td a:focus, table.m-table td.m-danger a:focus,
table.m-table tr.m-danger th a:focus, table.m-table th.m-danger a:focus,
.m-note.m-danger a:active,
table.m-table tr.m-danger td a:active, table.m-table td.m-danger a:active,
table.m-table tr.m-danger th a:active, table.m-table th.m-danger a:active { color: var(--danger-filled-link-active-color); }
.m-note.m-info,
table.m-table tr.m-info td, table.m-table td.m-info,
table.m-table tr.m-info th, table.m-table th.m-info { background-color: var(--info-filled-background-color); color: var(--info-filled-color); }
.m-note.m-info a,
table.m-table tr.m-info td a, table.m-table td.m-info a,
table.m-table tr.m-info th a, table.m-table th.m-info a { color: var(--info-filled-link-color); }
.m-note.m-info a:hover,
table.m-table tr.m-info td a:hover, table.m-table td.m-info a:hover,
table.m-table tr.m-info th a:hover, table.m-table th.m-info a:hover,
.m-note.m-info a:focus,
table.m-table tr.m-info td a:focus, table.m-table td.m-info a:focus,
table.m-table tr.m-info th a:focus, table.m-table th.m-info a:focus,
.m-note.m-info a:active,
table.m-table tr.m-info td a:active, table.m-table td.m-info a:active,
table.m-table tr.m-info th a:active, table.m-table th.m-info a:active { color: var(--info-filled-link-active-color); }
.m-note.m-dim,
table.m-table tr.m-dim td, table.m-table td.m-dim,
table.m-table tr.m-dim th, table.m-table th.m-dim { background-color: var(--dim-filled-background-color); color: var(--dim-filled-color); }
.m-note.m-dim a,
table.m-table tr.m-dim td a, table.m-table td.m-dim a,
table.m-table tr.m-dim th a, table.m-table th.m-dim a { color: var(--dim-filled-link-color); }
.m-note.m-dim a:hover,
table.m-table tr.m-dim td a:hover, table.m-table td.m-dim a:hover,
table.m-table tr.m-dim th a:hover, table.m-table th.m-dim a:hover,
.m-note.m-dim a:focus,
table.m-table tr.m-dim td a:focus, table.m-table td.m-dim a:focus,
table.m-table tr.m-dim th a:focus, table.m-table th.m-dim a:focus,
.m-note.m-dim a:active,
table.m-table tr.m-dim td a:active, table.m-table td.m-dim a:active,
table.m-table tr.m-dim th a:active, table.m-table th.m-dim a:active { color: var(--dim-filled-link-active-color); }
figure.m-figure.m-default::before { border-color: var(--default-filled-background-color); }
figure.m-figure.m-default figcaption { color: var(--default-color); }
figure.m-figure.m-primary::before { border-color: var(--primary-filled-background-color); }
figure.m-figure.m-primary figcaption { color: var(--primary-color); }
figure.m-figure.m-primary figcaption .m-figure-description { color: var(--default-color); }
figure.m-figure.m-success::before { border-color: var(--success-filled-background-color); }
figure.m-figure.m-success figcaption { color: var(--success-color); }
figure.m-figure.m-success figcaption .m-figure-description { color: var(--default-color); }
figure.m-figure.m-warning::before { border-color: var(--warning-filled-background-color); }
figure.m-figure.m-warning figcaption { color: var(--warning-color); }
figure.m-figure.m-warning figcaption .m-figure-description { color: var(--default-color); }
figure.m-figure.m-danger::before { border-color: var(--danger-filled-background-color); }
figure.m-figure.m-danger figcaption { color: var(--danger-color); }
figure.m-figure.m-danger figcaption .m-figure-description { color: var(--default-color); }
figure.m-figure.m-info::before { border-color: var(--info-filled-background-color); }
figure.m-figure.m-info figcaption { color: var(--info-color); }
figure.m-figure.m-info figcaption .m-figure-description { color: var(--default-color); }
figure.m-figure.m-dim::before { border-color: var(--dim-filled-background-color); }
figure.m-figure.m-dim { color: var(--dim-color); }
figure.m-figure.m-dim a { color: var(--dim-link-color); }
figure.m-figure.m-dim a:hover, figure.m-figure.m-dim a:focus, figure.m-figure.m-dim a:active { color: var(--dim-link-active-color); }
.m-math { fill: var(--color); }
.m-math.m-default, .m-math g.m-default, .m-math rect.m-default,
div.m-plot svg .m-bar.m-default,
.m-graph g.m-edge polygon,
.m-graph g.m-node:not(.m-flat) ellipse,
.m-graph g.m-node:not(.m-flat) polygon,
.m-graph g.m-edge text,
.m-graph g.m-node.m-flat text,
.m-graph g.m-cluster text,
.m-graph.m-default g.m-edge polygon,
.m-graph.m-default g.m-node:not(.m-flat) ellipse,
.m-graph.m-default g.m-node:not(.m-flat) polygon,
.m-graph.m-default g.m-edge text,
.m-graph.m-default g.m-node.m-flat text,
.m-graph.m-default g.m-cluster text { fill: var(--default-color); }
.m-graph g.m-edge polygon,
.m-graph g.m-edge path,
.m-graph g.m-node ellipse,
.m-graph g.m-node polygon,
.m-graph g.m-node polyline,
.m-graph g.m-cluster polygon,
.m-graph.m-default g.m-edge polygon,
.m-graph.m-default g.m-edge path,
.m-graph.m-default g.m-node ellipse,
.m-graph.m-default g.m-node polygon,
.m-graph.m-default g.m-node polyline,
.m-graph.m-default g.m-cluster polygon { stroke: var(--default-color); }
.m-math.m-primary, .m-math g.m-primary, .m-math rect.m-primary,
div.m-plot svg .m-bar.m-primary,
.m-graph.m-primary g.m-edge polygon,
.m-graph.m-primary g.m-node:not(.m-flat) ellipse,
.m-graph.m-primary g.m-node:not(.m-flat) polygon,
.m-graph.m-primary g.m-edge text,
.m-graph.m-primary g.m-node.m-flat text,
.m-graph.m-primary g.m-cluster text { fill: var(--primary-color); }
.m-graph.m-primary g.m-edge polygon,
.m-graph.m-primary g.m-edge path,
.m-graph.m-primary g.m-node ellipse,
.m-graph.m-primary g.m-node polygon,
.m-graph.m-primary g.m-node polyline,
.m-graph.m-primary g.m-cluster polygon { stroke: var(--primary-color); }
.m-math.m-success, .m-math g.m-success, .m-math rect.m-success,
div.m-plot svg .m-bar.m-success,
.m-graph.m-success g.m-edge polygon,
.m-graph.m-success g.m-node:not(.m-flat) ellipse,
.m-graph.m-success g.m-node:not(.m-flat) polygon,
.m-graph.m-success g.m-edge text,
.m-graph.m-success g.m-node.m-flat text,
.m-graph.m-success g.m-cluster text { fill: var(--success-color); }
.m-graph.m-success g.m-edge polygon,
.m-graph.m-success g.m-edge path,
.m-graph.m-success g.m-node ellipse,
.m-graph.m-success g.m-node polygon,
.m-graph.m-success g.m-node polyline,
.m-graph.m-success g.m-cluster polygon { stroke: var(--success-color); }
.m-math.m-warning, .m-math g.m-warning, .m-math rect.m-warning,
div.m-plot svg .m-bar.m-warning,
.m-graph.m-warning g.m-edge polygon,
.m-graph.m-warning g.m-node:not(.m-flat) ellipse,
.m-graph.m-warning g.m-node:not(.m-flat) polygon,
.m-graph.m-warning g.m-edge text,
.m-graph.m-warning g.m-node.m-flat text,
.m-graph.m-warning g.m-cluster text { fill: var(--warning-color); }
.m-graph.m-warning g.m-edge polygon,
.m-graph.m-warning g.m-edge path,
.m-graph.m-warning g.m-node ellipse,
.m-graph.m-warning g.m-node polygon,
.m-graph.m-warning g.m-node polyline,
.m-graph.m-warning g.m-cluster polygon { stroke: var(--warning-color); }
.m-math.m-danger, .m-math g.m-danger, .m-math rect.m-danger,
div.m-plot svg .m-bar.m-danger,
.m-graph.m-danger g.m-edge polygon,
.m-graph.m-danger g.m-node:not(.m-flat) ellipse,
.m-graph.m-danger g.m-node:not(.m-flat) polygon,
.m-graph.m-danger g.m-edge text,
.m-graph.m-danger g.m-node.m-flat text,
.m-graph.m-danger g.m-cluster text { fill: var(--danger-color); }
.m-graph.m-danger g.m-edge polygon,
.m-graph.m-danger g.m-edge path,
.m-graph.m-danger g.m-node ellipse,
.m-graph.m-danger g.m-node polygon,
.m-graph.m-danger g.m-node polyline,
.m-graph.m-danger g.m-cluster polygon { stroke: var(--danger-color); }
.m-math.m-info, .m-math g.m-info, .m-math rect.m-info,
div.m-plot svg .m-bar.m-info,
.m-graph.m-info g.m-edge polygon,
.m-graph.m-info g.m-node:not(.m-flat) ellipse,
.m-graph.m-info g.m-node:not(.m-flat) polygon,
.m-graph.m-info g.m-edge text,
.m-graph.m-info g.m-node.m-flat text,
.m-graph.m-info g.m-cluster text { fill: var(--info-color); }
.m-graph.m-info g.m-edge polygon,
.m-graph.m-info g.m-edge path,
.m-graph.m-info g.m-node ellipse,
.m-graph.m-info g.m-node polygon,
.m-graph.m-info g.m-node polyline,
.m-graph.m-info g.m-cluster polygon { stroke: var(--info-color); }
.m-math.m-dim, .m-math g.m-dim, .m-math rect.m-dim,
div.m-plot svg .m-bar.m-dim,
.m-graph.m-dim g.m-edge polygon,
.m-graph.m-dim g.m-node:not(.m-flat) ellipse,
.m-graph.m-dim g.m-node:not(.m-flat) polygon,
.m-graph.m-dim g.m-edge text,
.m-graph.m-dim g.m-node.m-flat text,
.m-graph.m-dim g.m-cluster text { fill: var(--dim-color); }
.m-graph.m-dim g.m-edge polygon,
.m-graph.m-dim g.m-edge path,
.m-graph.m-dim g.m-node ellipse,
.m-graph.m-dim g.m-node polygon,
.m-graph.m-dim g.m-node polyline,
.m-graph.m-dim g.m-cluster polygon { stroke: var(--dim-color); }
.m-graph g.m-edge.m-default polygon,
.m-graph g.m-node.m-default:not(.m-flat) ellipse,
.m-graph g.m-node.m-default:not(.m-flat) polygon,
.m-graph g.m-edge.m-default text,
.m-graph g.m-node.m-default.m-flat text,
.m-graph g.m-cluster.m-default text { fill: var(--default-color); }
.m-graph g.m-edge.m-default polygon,
.m-graph g.m-edge.m-default path,
.m-graph g.m-node.m-default ellipse,
.m-graph g.m-node.m-default polygon,
.m-graph g.m-node.m-default polyline,
.m-graph g.m-cluster.m-default polygon { stroke: var(--default-color); }
.m-graph g.m-edge.m-primary polygon,
.m-graph g.m-node.m-primary:not(.m-flat) ellipse,
.m-graph g.m-node.m-primary:not(.m-flat) polygon,
.m-graph g.m-edge.m-primary text,
.m-graph g.m-node.m-primary.m-flat text,
.m-graph g.m-cluster.m-primary text { fill: var(--primary-color); }
.m-graph g.m-edge.m-primary polygon,
.m-graph g.m-edge.m-primary path,
.m-graph g.m-node.m-primary ellipse,
.m-graph g.m-node.m-primary polygon,
.m-graph g.m-node.m-primary polyline,
.m-graph g.m-cluster.m-primary polygon { stroke: var(--primary-color); }
.m-graph g.m-edge.m-success polygon,
.m-graph g.m-node.m-success:not(.m-flat) ellipse,
.m-graph g.m-node.m-success:not(.m-flat) polygon,
.m-graph g.m-edge.m-success text,
.m-graph g.m-node.m-success.m-flat text,
.m-graph g.m-cluster.m-success text { fill: var(--success-color); }
.m-graph g.m-edge.m-success polygon,
.m-graph g.m-edge.m-success path,
.m-graph g.m-node.m-success ellipse,
.m-graph g.m-node.m-success polygon,
.m-graph g.m-node.m-success polyline,
.m-graph g.m-cluster.m-success polygon { stroke: var(--success-color); }
.m-graph g.m-edge.m-warning polygon,
.m-graph g.m-node.m-warning:not(.m-flat) ellipse,
.m-graph g.m-node.m-warning:not(.m-flat) polygon,
.m-graph g.m-edge.m-warning text,
.m-graph g.m-node.m-warning.m-flat text,
.m-graph g.m-cluster.m-warning text { fill: var(--warning-color); }
.m-graph g.m-edge.m-warning polygon,
.m-graph g.m-edge.m-warning path,
.m-graph g.m-node.m-warning ellipse,
.m-graph g.m-node.m-warning polygon,
.m-graph g.m-node.m-warning polyline,
.m-graph g.m-cluster.m-warning polygon { stroke: var(--warning-color); }
.m-graph g.m-edge.m-danger polygon,
.m-graph g.m-node.m-danger:not(.m-flat) ellipse,
.m-graph g.m-node.m-danger:not(.m-flat) polygon,
.m-graph g.m-edge.m-danger text,
.m-graph g.m-node.m-danger.m-flat text,
.m-graph g.m-cluster.m-danger text { fill: var(--danger-color); }
.m-graph g.m-edge.m-danger polygon,
.m-graph g.m-edge.m-danger path,
.m-graph g.m-node.m-danger ellipse,
.m-graph g.m-node.m-danger polygon,
.m-graph g.m-node.m-danger polyline,
.m-graph g.m-cluster.m-danger polygon { stroke: var(--danger-color); }
.m-graph g.m-edge.m-info polygon,
.m-graph g.m-node.m-info:not(.m-flat) ellipse,
.m-graph g.m-node.m-info:not(.m-flat) polygon,
.m-graph g.m-edge.m-info text,
.m-graph g.m-node.m-info.m-flat text,
.m-graph g.m-cluster.m-info text { fill: var(--info-color); }
.m-graph g.m-edge.m-info polygon,
.m-graph g.m-edge.m-info path,
.m-graph g.m-node.m-info ellipse,
.m-graph g.m-node.m-info polygon,
.m-graph g.m-node.m-info polyline,
.m-graph g.m-cluster.m-info polygon { stroke: var(--info-color); }
.m-graph g.m-edge.m-dim polygon,
.m-graph g.m-node.m-dim:not(.m-flat) ellipse,
.m-graph g.m-node.m-dim:not(.m-flat) polygon,
.m-graph g.m-edge.m-dim text,
.m-graph g.m-node.m-dim.m-flat text,
.m-graph g.m-cluster.m-dim text { fill: var(--dim-color); }
.m-graph g.m-edge.m-dim polygon,
.m-graph g.m-edge.m-dim path,
.m-graph g.m-node.m-dim ellipse,
.m-graph g.m-node.m-dim polygon,
.m-graph g.m-node.m-dim polyline,
.m-graph g.m-cluster.m-dim polygon { stroke: var(--dim-color); }
p, ul, ol, dl, blockquote, pre, .m-code-figure, .m-console-figure, hr, .m-note,
.m-frame, .m-block, div.m-button, div.m-scroll, table.m-table, div.m-image,
img.m-image, svg.m-image, figure.m-figure, .m-imagegrid, div.m-math,
div.m-graph, div.m-plot { margin-bottom: 1rem; }
p:last-child, p.m-nopadb, ul:last-child, ul.m-nopadb,
ol:last-child, ol.m-nopadb, dl:last-child, dl.m-nopadb,
blockquote:last-child, blockquote.m-nopadb, pre:last-child, pre.m-nopadb,
.m-code-figure:last-child, .m-code-figure.m-nopadb,
.m-console-figure:last-child, .m-console-figure.m-nopadb,
hr:last-child, hr.m-nopadb, .m-note:last-child, .m-note.m-nopadb,
.m-frame:last-child, .m-frame.m-nopadb, .m-block:last-child, .m-block.m-nopadb,
div.m-button:last-child, div.m-button.m-nopadb,
div.m-scroll:last-child, div.m-scroll.m-nopadb,
table.m-table:last-child, table.m-table.m-nopadb,
img.m-image:last-child, img.m-image.m-nopadb,
svg.m-image:last-child, svg.m-image.m-nopadb,
div.m-image:last-child, div.m-image.m-nopadb,
figure.m-figure:last-child, figure.m-figure.m-nopadb,
.m-imagegrid:last-child, .m-imagegrid.m-nopadb,
div.m-math:last-child, div.m-math.m-nopadb,
div.m-graph:last-child, div.m-graph.m-nopadb,
div.m-plot:last-child, div.m-plot.m-nopadb { margin-bottom: 0; }
li > p:last-child, li > blockquote:last-child, li > pre:last-child,
li > .m-code-figure:last-child, li > .m-console-figure:last-child,
li > .m-note:last-child, li > .m-frame:last-child, li > .m-block:last-child,
li > div.m-button:last-child, li > div.m-scroll:last-child, li > table.m-table:last-child,
li > img.m-image:last-child, li > svg.m-image:last-child, li > div.m-image:last-child,
li > figure.m-figure:last-child, li > div.m-math:last-child,
li > div.m-graph:last-child, li > div.m-plot:last-child { margin-bottom: 1rem; }
li:last-child > p:last-child, li:last-child > p.m-nopadb,
li:last-child > blockquote:last-child, li:last-child > blockquote.m-nopadb,
li:last-child > pre:last-child, li:last-child > pre.m-nopadb,
li:last-child > .m-code-figure:last-child, li:last-child > .m-code-figure.m-nopadb,
li:last-child > .m-console-figure:last-child, li:last-child > .m-console-figure.m-nopadb,
li:last-child > .m-note:last-child, li:last-child > .m-note.m-nopadb,
li:last-child > .m-frame:last-child, li:last-child > .m-frame.m-nopadb,
li:last-child > .m-block:last-child, li:last-child > .m-block.m-nopadb,
li:last-child > div.m-button:last-child, li:last-child > div.m-button.m-nopadb,
li:last-child > div.m-scroll:last-child, li:last-child > div.m-scroll.m-nopadb,
li:last-child > table.m-table:last-child, li:last-child > table.m-table.m-nopadb,
li:last-child > img.m-image:last-child, li:last-child > img.m-image.m-nopadb,
li:last-child > svg.m-image:last-child, li:last-child > svg.m-image.m-nopadb,
li:last-child > div.m-image:last-child, li:last-child > div.m-image.m-nopadb,
li:last-child > figure.m-figure:last-child, li:last-child > figure.m-figure.m-nopadb,
li:last-child > div.m-math:last-child, li:last-child > div.m-math.m-nopadb,
li:last-child > div.m-graph:last-child, li:last-child > div.m-graph.m-nopadb,
li:last-child > div.m-plot:last-child, li:last-child > div.m-plot.m-nopadb { margin-bottom: 0; }
/*==== m-special.css =================================================================================================*/
.m-special:not(.m-note, .m-button) a { color: var(--special-color); }
.m-special:not(.m-note, .m-button) a:hover,
.m-special:not(.m-note, .m-button) a:focus,
.m-special:not(.m-note, .m-button) a:active { color: var(--special-link-active-color); }
table.m-table td.m-special,
table.m-table th.m-special { padding-left: 0.4375rem; padding-right: 0.4375rem; border-left-width: 0.0625rem; }
table.m-table.m-big td.m-special,
table.m-table.m-big th.m-special { padding-left: 0.9375rem; padding-right: 0.9375rem; border-left-width: 0.0625rem; }
table.m-table tr.m-special td,
table.m-table td.m-special,
table.m-table tr.m-special th,
table.m-table th.m-special { border-color: var(--background-color); }
table.m-table tr.m-special pre,
table.m-table tr.m-special code,
table.m-table td.m-special pre,
table.m-table td.m-special code,
table.m-table th.m-special pre,
table.m-table th.m-special code { background-color: var(--code-note-background-color); }
.m-block.m-special { border-left-color: var(--special-color); }
.m-block.m-special h3,
.m-block.m-special h4,
.m-block.m-special h5,
.m-block.m-special h6,
.m-block.m-special h3 a,
.m-block.m-special h4 a,
.m-block.m-special h5 a,
.m-block.m-special h6 a,
.m-text.m-special,
.m-label.m-flat.m-special { color: var(--special-color); }
.m-block.m-special h3 a:hover,
.m-block.m-special h3 a:focus,
.m-block.m-special h3 a:active,
.m-block.m-special h4 a:hover,
.m-block.m-special h4 a:focus,
.m-block.m-special h4 a:active,
.m-block.m-special h5 a:hover,
.m-block.m-special h5 a:focus,
.m-block.m-special h5 a:active,
.m-block.m-special h6 a:hover,
.m-block.m-special h6 a:focus,
.m-block.m-special h6 a:active { color: var(--special-link-active-color); }
div.m-button.m-special a,
.m-label:not(.m-flat).m-special { background-color: var(--special-color); }
div.m-button.m-special a:hover,
div.m-button.m-special a:focus,
div.m-button.m-special a:active { background-color: var(--special-link-active-color); }
.m-note.m-special,
table.m-table tr.m-special td,
table.m-table td.m-special,
table.m-table tr.m-special th,
table.m-table th.m-special { background-color: var(--special-filled-background-color); color: var(--special-filled-color); }
.m-note.m-special a,
table.m-table tr.m-special td a,
table.m-table td.m-special a,
table.m-table tr.m-special th a,
table.m-table th.m-special a { color: var(--special-filled-link-color); }
.m-note.m-special a:hover,
table.m-table tr.m-special td a:hover,
table.m-table td.m-special a:hover,
table.m-table tr.m-special th a:hover,
table.m-table th.m-special a:hover,
.m-note.m-special a:focus,
table.m-table tr.m-special td a:focus,
table.m-table td.m-special a:focus,
table.m-table tr.m-special th a:focus,
table.m-table th.m-special a:focus,
.m-note.m-special a:active,
table.m-table tr.m-special td a:active,
table.m-table td.m-special a:active,
table.m-table tr.m-special th a:active,
table.m-table th.m-special a:active { color: var(--special-filled-link-active-color); }
figure.m-figure.m-special::before { border-color: var(--special-filled-background-color); }
figure.m-figure.m-special figcaption { color: var(--special-color); }
figure.m-figure.m-special figcaption .m-figure-description { color: var(--default-color); }
.m-math.m-special,
.m-math g.m-special,
.m-math rect.m-special,
div.m-plot svg .m-bar.m-special,
.m-graph.m-special g.m-edge polygon,
.m-graph.m-special g.m-node:not(.m-flat) ellipse,
.m-graph.m-special g.m-node:not(.m-flat) polygon,
.m-graph.m-special g.m-edge text,
.m-graph.m-special g.m-node.m-flat text,
.m-graph.m-special g.m-cluster text { fill: var(--special-color); }
.m-graph.m-special g.m-edge polygon,
.m-graph.m-special g.m-edge path,
.m-graph.m-special g.m-node ellipse,
.m-graph.m-special g.m-node polygon,
.m-graph.m-special g.m-node polyline,
.m-graph.m-special g.m-cluster polygon { stroke: var(--special-color); }
.m-graph g.m-edge.m-special polygon,
.m-graph g.m-node.m-special:not(.m-flat) ellipse,
.m-graph g.m-node.m-special:not(.m-flat) polygon,
.m-graph g.m-edge.m-special text,
.m-graph g.m-node.m-special.m-flat text,
.m-graph g.m-cluster.m-special text { fill: var(--special-color); }
.m-graph g.m-edge.m-special polygon,
.m-graph g.m-edge.m-special path,
.m-graph g.m-node.m-special ellipse,
.m-graph g.m-node.m-special polygon,
.m-graph g.m-node.m-special polyline,
.m-graph g.m-cluster.m-special polygon { stroke: var(--special-color); }
.m-container-inflatable section:target .m-note.m-info { border-color: var(--info-color); }
/*==== ../mcss/css/m-layout.css ======================================================================================*/
body > header > nav { width: 100%; background-color: var(--header-background-color); min-height: 3rem; }
body > header > nav.m-navbar-landing,
body > header > nav.m-navbar-cover { background-color: transparent; position: relative; }
body > header > nav.m-navbar-landing { opacity: 0.8; }
body > header > nav.m-navbar-cover { background-color: var(--header-background-color-jumbo); opacity: 1; }
body > header > nav.m-navbar-landing:hover,
body > header > nav.m-navbar-cover:hover { background-color: var(--header-background-color-landing); opacity: 1; }
body> header > nav.m-navbar-landing:target,
body> header > nav.m-navbar-cover:target { background-color: var(--header-background-color); opacity: 1; }
body > header > nav.m-navbar-landing #m-navbar-brand.m-navbar-brand-hidden { visibility: hidden; }
body > header > nav.m-navbar-landing:target #m-navbar-brand.m-navbar-brand-hidden { visibility: visible; }
body > header > nav { margin-left: auto; margin-right: auto; color: var(--header-color); }
body > header > nav a {
text-decoration: var(--link-decoration-nav);
text-transform: var(--nav-menu-case);
display: inline-block;
vertical-align: middle;
line-height: 2.75rem;
color: var(--header-link-color);
}
body > header > nav #m-navbar-brand, body > header > nav a#m-navbar-show, body > header > nav a#m-navbar-hide {
font-weight: var(--heading-font-weight);
font-size: 1.125rem;
padding-left: 1rem;
padding-right: 1rem;
}
body > header > nav a#m-navbar-brand, body > header > nav #m-navbar-brand a { text-transform: var(--nav-brand-case); }
body > header > nav a#m-navbar-brand img, body > header > nav #m-navbar-brand a img { width: 1.75rem; height: 1.75rem; vertical-align: -22.5%; margin-right: 0.5rem; }
body > header > nav #m-navbar-brand a { padding-left: 0; padding-right: 0; }
body > header > nav #m-navbar-brand .m-thin { font-weight: normal; }
body > header > nav #m-navbar-brand .m-breadcrumb { color: var(--header-breadcrumb-color); }
body > header > nav a#m-navbar-show::before, body > header > nav a#m-navbar-hide::before { content:'\2630'; }
body > header > nav #m-navbar-collapse { padding-bottom: 1rem; }
body > header > nav #m-navbar-collapse li { border-style: solid; border-color: transparent; border-width: 0 0 0 0.25rem; margin-left: -1rem; }
body > header > nav #m-navbar-collapse li a {
border-style: solid;
border-color: transparent;
line-height: 1.5rem;
margin-left: -0.25rem;
padding-left: 0.75rem;
border-width: 0 0 0 0.25rem;
width: 100%;
}
body > header > nav #m-navbar-collapse li a#m-navbar-current { color: var(--header-link-current-color); border-color: var(--header-link-current-color); }
body > header > nav ol { list-style-type: none; margin: 0; }
body > header > nav ol ol { padding-left: 1.5rem; }
body > header > nav .m-row > [class*='m-col-'] { padding-top: 0; padding-bottom: 0; }
body > header > nav a:hover, body > header > nav a:focus, body > header > nav a:active { color: var(--header-link-active-color); }
body > header > nav #m-navbar-collapse li:hover { border-color: var(--header-link-active-color); }
body > header > nav #m-navbar-collapse li a:hover,
body > header > nav #m-navbar-collapse li a:focus,
body > header > nav #m-navbar-collapse li a:active {
border-color: var(--header-link-active-color);
background-color: var(--header-link-active-background-color);
}
body > header > nav.m-navbar-landing #m-navbar-collapse li a:hover,
body > header > nav.m-navbar-cover #m-navbar-collapse li a:hover,
body > header > nav.m-navbar-landing #m-navbar-collapse li a:focus,
body > header > nav.m-navbar-cover #m-navbar-collapse li a:focus,
body > header > nav.m-navbar-landing #m-navbar-collapse li a:active,
body > header > nav.m-navbar-cover #m-navbar-collapse li a:active { background-color: var(--header-link-active-background-color-semi); }
body > header > nav #m-navbar-hide { display: none; }
body > header > nav:target #m-navbar-collapse { display: block; }
body > header > nav:target #m-navbar-show { display: none; }
body > header > nav:target #m-navbar-hide { display: inline-block; }
@media screen and (min-width: 768px) {
body > header > nav #m-navbar-show, body > header > nav #m-navbar-hide,
body > header > nav:target #m-navbar-show, body > header > nav:target #m-navbar-hide { display: none; }
body > header > nav #m-navbar-collapse li a { line-height: 2.75rem; }
body > header > nav a, body > header > nav #m-navbar-collapse li a { margin-left: 0; padding-left: 1rem; padding-right: 1rem; white-space: nowrap; }
body > header > nav #m-navbar-collapse { padding-bottom: 0; }
body > header > nav #m-navbar-collapse li ol { background-color: var(--header-background-color); }
body > header > nav #m-navbar-collapse ol ol li { margin-left: 0; padding-left: 0; border-left-width: 0; }
body > header > nav #m-navbar-collapse ol ol li a { padding-left: 0.75rem; }
body > header > nav #m-navbar-collapse > .m-row > ol > li { margin-left: 0; border-left-width: 0; }
body > header > nav #m-navbar-collapse > .m-row > ol > li > a { border-width: var(--header-border-width); }
body > header > nav #m-navbar-collapse ol { padding-left: 0; padding-right: 0; }
body > header > nav #m-navbar-collapse > .m-row > ol, body > header > nav #m-navbar-collapse > .m-row > ol > li { float: left; }
body > header > nav #m-navbar-collapse ol ol { z-index: 99999; position: absolute; visibility: hidden; }
body > header > nav #m-navbar-collapse li:hover ol { visibility: visible; }
}
body > footer { width: 100%; }
body > footer > nav {
padding-top: 1rem;
padding-bottom: 1rem;
font-size: var(--footer-font-size);
text-align: center;
color: var(--footer-color);
background-color: var(--footer-background-color);
}
body > footer > nav h3, body > footer > nav h3 a { text-transform: var(--nav-heading-case); font-weight: normal; }
body > footer > nav ul { list-style-type: none; padding: 0; margin: 0; }
body > footer > nav a {
text-decoration: var(--link-decoration-nav);
text-transform: var(--nav-menu-case);
color: var(--footer-link-color);
}
body > footer > nav a:hover, body > footer > nav a:focus, body > footer > nav a:active { color: var(--footer-link-active-color); }
body > main { padding-top: 1rem; padding-bottom: 1rem; }
article h1 { font-size: 1.75rem; }
article h1 .m-breadcrumb { color: var(--dim-color); font-weight: normal; }
article h1 .m-breadcrumb a { color: var(--article-heading-color); }
article h1 .m-breadcrumb a:hover, article h1 a:focus, article h1 a:active { color: var(--article-heading-active-color); }
article > header h1 { font-size: 2rem; margin-bottom: 0.5rem; }
article h1 a, article > header h1, article > header h1 a,
article section > h2, article section > h2 a,
article section > h3, article section > h3 a,
article section > h4, article section > h4 a,
article section > h5, article section > h5 a,
article section > h6, article section > h6 a { color: var(--article-heading-color); }
article h1 a:hover, article > header h1 a:hover, article > header h1 a:focus, article > header h1 a:active,
article section > h2 a:hover, article section > h2 a:focus, article section > h2 a:active,
article section > h3 a:hover, article section > h3 a:focus, article section > h3 a:active,
article section > h4 a:hover, article section > h4 a:focus, article section > h4 a:active,
article section > h5 a:hover, article section > h5 a:focus, article section > h5 a:active,
article section > h6 a:hover, article section > h6 a:focus, article section > h6 a:active { color: var(--article-heading-active-color); }
article > header .m-date {
display: block;
width: 2.5rem;
float: left;
text-align: center;
line-height: 95%;
font-size: 0.75rem;
font-weight: normal;
white-space: nowrap;
border-right-style: solid;
border-right-width: 0.125rem;
border-color: var(--article-heading-color);
padding-right: 0.75rem;
margin-top: -0.1rem;
margin-right: 0.75rem;
margin-bottom: 0.25rem;
}
article > header .m-date-day { display: block; font-weight: bold; padding-top: 0.2rem; padding-bottom: 0.15rem; font-size: 1.25rem; }
article > header p { color: var(--article-header-color); font-size: 1.125rem; }
article > header h1::after { content: " "; clear: both; display: table; }
article > footer { color: var(--article-footer-color); }
article > footer p { font-style: italic; font-size: 0.85rem; text-indent: 0; }
article section:target {
margin-left: -1.0rem;
border-left-style: solid;
border-left-width: 0.25rem;
padding-left: 0.75rem;
border-color: var(--article-heading-color);
}
article h1 a, article > header h1 a, article section > h2 a, article section > h3 a,
article section > h4 a, article section > h5 a, article section > h6 a { text-decoration: var(--link-decoration-heading); }
#m-landing-image, #m-cover-image, article#m-jumbo > header #m-jumbo-image {
background-size: cover;
background-color: var(--cover-image-background-color);
background-position: center center;
background-repeat: no-repeat;
margin-top: -4rem;
padding-top: 5rem;
}
#m-landing-image { color: #ffffff; }
#m-cover-image { height: 30rem; margin-bottom: -26rem; }
#m-landing-cover h1 {
font-size: 2.8rem;
margin-top: -0.5rem;
padding-left: var(--paragraph-indent);
padding-bottom: 1rem;
text-transform: var(--landing-header-case);
}
#m-landing-cover { padding-bottom: 10rem; margin-bottom: -6rem; }
article#m-jumbo { margin-top: -1rem; }
#m-landing-cover, #m-cover-image > div, article#m-jumbo > header #m-jumbo-cover {
background: linear-gradient(transparent 0%, transparent 50%, var(--background-color) 100%);
width: 100%;
height: 100%;
}
article#m-jumbo > header h1, article#m-jumbo > header h2 { text-align: center; font-weight: bold; }
article#m-jumbo > header a { text-decoration: none; }
article#m-jumbo > header #m-jumbo-cover { padding-bottom: 5rem; }
article#m-jumbo > header #m-jumbo-image { font-size: 2vmin; margin-bottom: -3rem; }
article#m-jumbo > header h1 { font-size: 8vmin; }
article#m-jumbo > header h2 { font-size: 3vmin; }
@media screen and (max-height: 640px) , screen and (max-width: 640px) {
article#m-jumbo > header h1 { font-size: 3rem; }
article#m-jumbo > header #m-jumbo-image, article#m-jumbo > header h2 { font-size: 1rem; }
}
article#m-jumbo > header, article#m-jumbo > header h1, article#m-jumbo > header a { color: #ffffff; }
article#m-jumbo > header a:hover, article#m-jumbo > header a:focus, article#m-jumbo > header a:active { color: #f0f0f0; }
article#m-jumbo.m-inverted > header, article#m-jumbo.m-inverted > header h1, article#m-jumbo.m-inverted > header a { color: #000000; }
article#m-jumbo.m-inverted > header a:hover, article#m-jumbo.m-inverted > header a:focus, article#m-jumbo.m-inverted > header a:active { color: #0f0f0f; }
.m-landing-news h3 a { color: var(--color); text-decoration: none; text-transform: var(--nav-heading-case); }
.m-landing-news h3 a:hover, .m-landing-news h3 a:hover, .m-landing-news h3 a:focus, .m-landing-news h3 a:active { color: var(--article-heading-color); }
.m-landing-news time { display: inline-block; margin-left: 1rem; float: right; }
.m-article-pagination { text-align: center; padding: 1rem; }
nav.m-navpanel { text-align: center; }
nav.m-navpanel h3 { text-transform: var(--nav-heading-case); font-weight: normal; }
nav.m-navpanel ol { text-transform: var(--nav-categories-case); }
nav.m-navpanel ol, nav.m-navpanel ul { list-style-type: none; padding: 0; }
nav.m-navpanel a { color: var(--navpanel-link-color); text-decoration: var(--link-decoration-nav); }
nav.m-navpanel a:hover, nav.m-navpanel a:focus, nav.m-navpanel a:active { color: var(--navpanel-link-active-color); }
ul.m-tagcloud li { display: inline; }
ul.m-tagcloud li.m-tag-1 { font-size: 0.75rem; }
ul.m-tagcloud li.m-tag-2 { font-size: 0.825rem; }
ul.m-tagcloud li.m-tag-3 { font-size: 1rem; }
ul.m-tagcloud li.m-tag-4 { font-size: 1.25rem; }
ul.m-tagcloud li.m-tag-5 { font-size: 1.5rem; }
article section:target figure.m-code-figure, article section:target figure.m-console-figure { z-index: 1; }
article, article > header, article section { margin-bottom: 1rem; }
article:last-child, article section:last-child { margin-bottom: 0; }
.m-container-inflatable section:target > .m-note,
.m-container-inflatable section:target > .m-frame,
.m-container-inflatable section:target > .m-block,
.m-container-inflatable section:target > pre,
.m-container-inflatable section:target > .m-code-figure > pre:first-child,
.m-container-inflatable section:target > .m-console-figure > pre:first-child,
.m-container-inflatable section:target section > .m-note,
.m-container-inflatable section:target section > .m-frame,
.m-container-inflatable section:target section > .m-block,
.m-container-inflatable section:target section > pre,
.m-container-inflatable section:target section > .m-code-figure > pre:first-child,
.m-container-inflatable section:target section > .m-console-figure > pre:first-child,
.m-container-inflatable section:target [class*='m-center-'] > .m-note,
.m-container-inflatable section:target [class*='m-center-'] > .m-frame,
.m-container-inflatable section:target [class*='m-center-'] > .m-block,
.m-container-inflatable section:target [class*='m-center-'] > pre,
.m-container-inflatable section:target [class*='m-center-'] > .m-code-figure > pre:first-child,
.m-container-inflatable section:target [class*='m-center-'] > .m-console-figure > pre:first-child,
.m-container-inflatable section:target [class*='m-left-'] > .m-note,
.m-container-inflatable section:target [class*='m-left-'] > .m-frame,
.m-container-inflatable section:target [class*='m-left-'] > .m-block,
.m-container-inflatable section:target [class*='m-left-'] > pre,
.m-container-inflatable section:target [class*='m-left-'] > .m-code-figure > pre:first-child,
.m-container-inflatable section:target [class*='m-left-'] > .m-console-figure > pre:first-child,
.m-container-inflatable section:target [class*='m-right-'] > .m-note,
.m-container-inflatable section:target [class*='m-right-'] > .m-frame,
.m-container-inflatable section:target [class*='m-right-'] > .m-block,
.m-container-inflatable section:target [class*='m-right-'] > pre,
.m-container-inflatable section:target [class*='m-right-'] > .m-code-figure > pre:first-child,
.m-container-inflatable section:target [class*='m-right-'] > .m-console-figure > pre:first-child,
.m-container-inflatable section:target .m-container-inflate > .m-note,
.m-container-inflatable section:target .m-container-inflate > .m-frame,
.m-container-inflatable section:target .m-container-inflate > .m-block,
.m-container-inflatable section:target .m-container-inflate > pre,
.m-container-inflatable section:target .m-container-inflate > .m-code-figure > pre:first-child,
.m-container-inflatable section:target .m-container-inflate > .m-console-figure > pre:first-child {
margin-left: -1.0rem;
border-left-style: solid;
border-left-width: 0.25rem;
border-top-left-radius: 0;
border-bottom-left-radius: 0;
padding-left: 0.75rem;
}
.m-container-inflatable section:target > .m-code-figure::before,
.m-container-inflatable section:target > .m-console-figure::before,
.m-container-inflatable section:target section > .m-code-figure::before,
.m-container-inflatable section:target section > .m-console-figure::before,
.m-container-inflatable section:target [class*='m-center-'] > .m-code-figure::before,
.m-container-inflatable section:target [class*='m-center-'] > .m-console-figure::before,
.m-container-inflatable section:target [class*='m-left-'] > .m-code-figure::before,
.m-container-inflatable section:target [class*='m-left-'] > .m-console-figure::before,
.m-container-inflatable section:target [class*='m-right-'] > .m-code-figure::before,
.m-container-inflatable section:target [class*='m-right-'] > .m-console-figure::before,
.m-container-inflatable section:target .m-container-inflate > .m-code-figure::before,
.m-container-inflatable section:target .m-container-inflate > .m-console-figure::before { border-top-left-radius: 0; border-bottom-left-radius: 0; border-left-width: 0.25rem; }
.m-container-inflatable section:target > .m-code-figure > pre.m-nopad,
.m-container-inflatable section:target > .m-console-figure > pre.m-nopad { margin-left: -0.75rem; padding-left: -0.75rem; }
@media screen and (min-width: 576px) {
.m-container-inflatable section:target .m-center-s > .m-note,
.m-container-inflatable section:target .m-center-s > pre,
.m-container-inflatable section:target .m-center-s > figure.m-code-figure > pre:first-child,
.m-container-inflatable section:target .m-center-s > figure.m-console-figure > pre:first-child,
.m-container-inflatable section:target .m-right-s > figure.m-code-figure > pre:first-child,
.m-container-inflatable section:target .m-right-s > figure.m-console-figure > pre:first-child {
border-left-width: 0;
border-top-left-radius: var(--border-radius);
border-bottom-left-radius: var(--border-radius);
padding-left: 1rem;
}
.m-container-inflatable section:target .m-center-s > .m-block,
.m-container-inflatable section:target .m-right-s > .m-block { border-top-left-radius: var(--border-radius); border-bottom-left-radius: var(--border-radius); }
.m-container-inflatable section:target .m-center-s > .m-frame,
.m-container-inflatable section:target .m-right-s > .m-frame {
border-top-left-radius: var(--border-radius);
border-bottom-left-radius: var(--border-radius);
border-left-width: 0.125rem;
padding-left: 0.875rem;
}
.m-container-inflatable section:target .m-right-s > .m-block,
.m-container-inflatable section:target .m-right-s > .m-frame { margin-left: 0; }
.m-container-inflatable section:target .m-right-s > .m-note,
.m-container-inflatable section:target .m-right-s > pre {
border-top-left-radius: var(--border-radius);
border-bottom-left-radius: var(--border-radius);
margin-left: 0;
border-left-width: 0;
padding-left: 1rem;
}
.m-container-inflatable section:target .m-center-s > figure.m-code-figure::before,
.m-container-inflatable section:target .m-center-s > figure.m-console-figure::before,
.m-container-inflatable section:target .m-right-s > figure.m-code-figure::before,
.m-container-inflatable section:target .m-right-s > figure.m-console-figure::before {
border-top-left-radius: var(--border-radius);
border-bottom-left-radius: var(--border-radius);
border-left-width: 0.125rem;
}
}
@media screen and (min-width: 768px) {
.m-container-inflatable section:target .m-center-m > .m-note,
.m-container-inflatable section:target .m-center-m > pre,
.m-container-inflatable section:target .m-center-m > figure.m-code-figure > pre:first-child,
.m-container-inflatable section:target .m-center-m > figure.m-console-figure > pre:first-child,
.m-container-inflatable section:target .m-right-m > figure.m-code-figure > pre:first-child,
.m-container-inflatable section:target .m-right-m > figure.m-console-figure > pre:first-child {
border-left-width: 0;
border-top-left-radius: var(--border-radius);
border-bottom-left-radius: var(--border-radius);
padding-left: 1rem;
}
.m-container-inflatable section:target .m-center-m > .m-block,
.m-container-inflatable section:target .m-right-m > .m-block { border-top-left-radius: var(--border-radius); border-bottom-left-radius: var(--border-radius); }
.m-container-inflatable section:target .m-center-m > .m-frame,
.m-container-inflatable section:target .m-right-m > .m-frame {
border-top-left-radius: var(--border-radius);
border-bottom-left-radius: var(--border-radius);
border-left-width: 0.125rem;
padding-left: 0.875rem;
}
.m-container-inflatable section:target .m-right-m > .m-block,
.m-container-inflatable section:target .m-right-m > .m-frame { margin-left: 0; }
.m-container-inflatable section:target .m-right-m > .m-note,
.m-container-inflatable section:target .m-right-m > pre {
border-top-left-radius: var(--border-radius);
border-bottom-left-radius: var(--border-radius);
margin-left: 0;
border-left-width: 0;
padding-left: 1rem;
}
.m-container-inflatable section:target .m-center-m > figure.m-code-figure::before,
.m-container-inflatable section:target .m-center-m > figure.m-console-figure::before,
.m-container-inflatable section:target .m-right-m > figure.m-code-figure::before,
.m-container-inflatable section:target .m-right-m > figure.m-console-figure::before {
border-top-left-radius: var(--border-radius);
border-bottom-left-radius: var(--border-radius);
border-left-width: 0.125rem;
}
}
@media screen and (min-width: 992px) {
.m-container-inflatable section:target .m-center-l > .m-note,
.m-container-inflatable section:target .m-center-l > pre,
.m-container-inflatable section:target .m-center-l > figure.m-code-figure > pre:first-child,
.m-container-inflatable section:target .m-center-l > figure.m-console-figure > pre:first-child,
.m-container-inflatable section:target .m-right-l > figure.m-code-figure > pre:first-child,
.m-container-inflatable section:target .m-right-l > figure.m-console-figure > pre:first-child {
border-left-width: 0;
border-top-left-radius: var(--border-radius);
border-bottom-left-radius: var(--border-radius);
padding-left: 1rem;
}
.m-container-inflatable section:target .m-center-l > .m-block,
.m-container-inflatable section:target .m-right-l > .m-block { border-top-left-radius: var(--border-radius); border-bottom-left-radius: var(--border-radius); }
.m-container-inflatable section:target .m-center-l > .m-frame,
.m-container-inflatable section:target .m-right-l > .m-frame {
border-top-left-radius: var(--border-radius);
border-bottom-left-radius: var(--border-radius);
border-left-width: 0.125rem;
padding-left: 0.875rem;
}
.m-container-inflatable section:target .m-right-l > .m-block,
.m-container-inflatable section:target .m-right-l > .m-frame { margin-left: 0; }
.m-container-inflatable section:target .m-right-l > .m-note,
.m-container-inflatable section:target .m-right-l > pre {
border-top-left-radius: var(--border-radius);
border-bottom-left-radius: var(--border-radius);
margin-left: 0;
border-left-width: 0;
padding-left: 1rem;
}
.m-container-inflatable section:target .m-center-l > figure.m-code-figure::before,
.m-container-inflatable section:target .m-center-l > figure.m-console-figure::before,
.m-container-inflatable section:target .m-right-l > figure.m-code-figure::before,
.m-container-inflatable section:target .m-right-l > figure.m-console-figure::before {
border-top-left-radius: var(--border-radius);
border-bottom-left-radius: var(--border-radius);
border-left-width: 0.125rem;
}
}
.m-container-inflatable section:target > figure.m-code-figure::before,
.m-container-inflatable section:target > figure.m-console-figure::before,
.m-container-inflatable section:target section > figure.m-code-figure::before,
.m-container-inflatable section:target section > figure.m-console-figure::before,
.m-container-inflatable section:target [class*='m-center-'] > figure.m-code-figure::before,
.m-container-inflatable section:target [class*='m-center-'] > figure.m-console-figure::before,
.m-container-inflatable section:target [class*='m-left-'] > figure.m-code-figure::before,
.m-container-inflatable section:target [class*='m-left-'] > figure.m-console-figure::before,
.m-container-inflatable section:target [class*='m-right-'] > figure.m-code-figure::before,
.m-container-inflatable section:target [class*='m-right-'] > figure.m-console-figure::before,
.m-container-inflatable section:target .m-container-inflatable > figure.m-code-figure::before,
.m-container-inflatable section:target .m-container-inflatable > figure.m-console-figure::before { border-left-color: var(--line-color); }
@media screen and (min-width: 576px) {
.m-container-inflatable section:target .m-center-s > figure.m-code-figure::before,
.m-container-inflatable section:target .m-right-s > figure.m-code-figure::before { border-color: var(--code-background-color); }
.m-container-inflatable section:target .m-center-s > figure.m-console-figure::before,
.m-container-inflatable section:target .m-right-s > figure.m-console-figure::before { border-color: var(--console-background-color); }
}
@media screen and (min-width: 768px) {
.m-container-inflatable section:target .m-center-m > figure.m-code-figure::before,
.m-container-inflatable section:target .m-right-m > figure.m-code-figure::before { border-color: var(--code-background-color); }
.m-container-inflatable section:target .m-center-m > figure.m-console-figure::before,
.m-container-inflatable section:target .m-right-m > figure.m-console-figure::before { border-color: var(--console-background-color); }
}
@media screen and (min-width: 992px) {
.m-container-inflatable section:target .m-center-l > figure.m-code-figure::before,
.m-container-inflatable section:target .m-right-l > figure.m-code-figure::before { border-color: var(--code-background-color); }
.m-container-inflatable section:target .m-center-l > figure.m-console-figure::before,
.m-container-inflatable section:target .m-right-l > figure.m-console-figure::before { border-color: var(--console-background-color); }
}
.m-container-inflatable section:target pre,
.m-container-inflatable section:target figure.m-code-figure > pre:first-child,
.m-container-inflatable section:target figure.m-console-figure > pre:first-child { border-color: var(--line-color); }
.m-container-inflatable section:target .m-note.m-default { border-color: var(--line-color); }
.m-container-inflatable section:target .m-note.m-primary { border-color: var(--primary-color); }
.m-container-inflatable section:target .m-note.m-success { border-color: var(--success-color); }
.m-container-inflatable section:target .m-note.m-warning { border-color: var(--warning-color); }
.m-container-inflatable section:target .m-note.m-danger { border-color: var(--danger-color); }
.m-container-inflatable section:target .m-note.m-info { border-color: var(--info-color); }
.m-container-inflatable section:target .m-note.m-dim { border-color: var(--dim-color); }
/*==== poxy-pygments.css =============================================================================================*/
.m-code .hll { background-color: #34424d }
.m-code .c { color: var(--code-color-comments); }
.m-code .n { color: var(--code-color-identifiers); }
.m-code .o { color: var(--code-color-operators); }
.m-code .p { color: var(--code-color-punctuation); }
.m-code .ch { color: var(--code-color-comments); }
.m-code .cm { color: var(--code-color-comments); }
.m-code .cp { color: var(--code-color-preprocessor); }
.m-code .cpf { color: var(--code-color-strings); }
.m-code .c1 { color: var(--code-color-comments); }
.m-code .cs { color: var(--code-color-comments); }
.m-code .gd { color: #cd3431 }
.m-code .ge { color: #e6e6e6; font-style: italic }
.m-code .gh { color: #ffffff; font-weight: bold }
.m-code .gi { color: #3bd267 }
.m-code .gs { color: #e6e6e6; font-weight: bold }
.m-code .gu { color: #5b9dd9 }
.m-code .k { color: var(--code-color-keywords); }
.m-code .kc { color: var(--code-color-keywords); }
.m-code .kd { color: var(--code-color-keywords); }
.m-code .kn { color: var(--code-color-keywords); }
.m-code .kp { color: var(--code-color-keywords); }
.m-code .kr { color: var(--code-color-keywords); }
.m-code .kt { color: var(--code-color-keywords); }
.m-code .m { color: var(--code-color-numbers); }
.m-code .s { color: var(--code-color-strings); }
.m-code .na { color: var(--code-color-identifiers); }
.m-code .nb { color: var(--code-color-functions); }
.m-code .nc { color: var(--code-color-typenames); }
.m-code .no { color: var(--code-color-identifiers); }
.m-code .nd { color: var(--code-color-identifiers); }
.m-code .ni { color: var(--code-color-identifiers); }
.m-code .ne { color: var(--code-color-typenames); }
.m-code .nf { color: var(--code-color-functions); }
.m-code .nl { color: var(--code-color-identifiers); }
.m-code .nn { color: var(--code-color-namespaces); }
.m-code .nx { color: var(--code-color-identifiers); }
.m-code .py { color: var(--code-color-identifiers); }
.m-code .nt { color: var(--code-color-identifiers); }
.m-code .nv { color: var(--code-color-identifiers); }
.m-code .ow { color: var(--code-color-operators); }
.m-code .mb { color: var(--code-color-numbers); }
.m-code .mf { color: var(--code-color-numbers); }
.m-code .mh { color: var(--code-color-numbers); }
.m-code .mi { color: var(--code-color-numbers); }
.m-code .mo { color: var(--code-color-numbers); }
.m-code .sa { color: var(--code-color-strings); }
.m-code .sb { color: var(--code-color-strings); }
.m-code .sc { color: var(--code-color-strings); }
.m-code .dl { color: var(--code-color-strings); }
.m-code .sd { color: var(--code-color-strings); }
.m-code .s2 { color: var(--code-color-strings); }
.m-code .se { color: var(--code-color-escapes); }
.m-code .sh { color: var(--code-color-strings); }
.m-code .si { color: #a5c9ea }
.m-code .sx { color: var(--code-color-strings); }
.m-code .sr { color: var(--code-color-strings); }
.m-code .s1 { color: var(--code-color-strings); }
.m-code .ss { color: var(--code-color-strings); }
.m-code .bp { color: var(--code-color-functions); }
.m-code .fm { color: var(--code-color-macros); }
.m-code .vc { color: var(--code-color-identifiers); }
.m-code .vg { color: var(--code-color-identifiers); }
.m-code .vi { color: var(--code-color-identifiers); }
.m-code .vm { color: var(--code-color-identifiers); }
.m-code .il { color: var(--code-color-numbers); }
.m-console .hll { background-color: #ffffcc }
.m-console .g-AnsiBackgroundBlack { background-color: #232627 }
.m-console .g-AnsiBackgroundBlue { background-color: #1d99f3 }
.m-console .g-AnsiBackgroundBrightBlack { background-color: #7f8c8d }
.m-console .g-AnsiBackgroundBrightBlue { background-color: #3daee9 }
.m-console .g-AnsiBackgroundBrightCyan { background-color: #16a085 }
.m-console .g-AnsiBackgroundBrightGreen { background-color: #1cdc9a }
.m-console .g-AnsiBackgroundBrightMagenta { background-color: #8e44ad }
.m-console .g-AnsiBackgroundBrightRed { background-color: #c0392b }
.m-console .g-AnsiBackgroundBrightWhite { background-color: #ffffff }
.m-console .g-AnsiBackgroundBrightYellow { background-color: #fdbc4b }
.m-console .g-AnsiBackgroundCyan { background-color: #1abc9c }
.m-console .g-AnsiBackgroundGreen { background-color: #11d116 }
.m-console .g-AnsiBackgroundMagenta { background-color: #9b59b6 }
.m-console .g-AnsiBackgroundRed { background-color: #ed1515 }
.m-console .g-AnsiBackgroundWhite { background-color: #fcfcfc }
.m-console .g-AnsiBackgroundYellow { background-color: #f67400 }
.m-console .g-AnsiBlack { color: #232627 }
.m-console .g-AnsiBlue { color: #1d99f3 }
.m-console .g-AnsiBrightBlack { color: #7f8c8d; font-weight: bold }
.m-console .g-AnsiBrightBlue { color: #3daee9; font-weight: bold }
.m-console .g-AnsiBrightCyan { color: #16a085; font-weight: bold }
.m-console .g-AnsiBrightDefault { color: #ffffff; font-weight: bold }
.m-console .g-AnsiBrightGreen { color: #1cdc9a; font-weight: bold }
.m-console .g-AnsiBrightMagenta { color: #8e44ad; font-weight: bold }
.m-console .g-AnsiBrightRed { color: #c0392b; font-weight: bold }
.m-console .g-AnsiBrightWhite { color: #ffffff; font-weight: bold }
.m-console .g-AnsiBrightYellow { color: #fdbc4b; font-weight: bold }
.m-console .g-AnsiCyan { color: #1abc9c }
.m-console .g-AnsiGreen { color: #11d116 }
.m-console .g-AnsiMagenta { color: #9b59b6 }
.m-console .g-AnsiRed { color: #ed1515 }
.m-console .g-AnsiWhite { color: #fcfcfc }
.m-console .g-AnsiYellow { color: #f67400 }
.m-console .go { color: var(--console-color); }
.m-console .gp { color: #16a085; font-weight: bold }
.m-console .w { color: var(--console-color); }
/*==== ../mcss/css/m-documentation.css ===============================================================================*/
a.m-doc, a.m-doc-self, a.m-doc-external,
ul.m-doc li.m-doc-expansible > a:first-child, ul.m-doc li.m-doc-collapsible > a:first-child,
.m-code.m-inverted.m-doc-include > a { text-decoration: none; }
a.m-doc, a.m-doc-self { font-weight: bold; }
.m-thin a.m-doc, .m-thin a.m-doc-self { font-weight: normal; }
ul.m-doc li.m-doc-expansible > a:first-child,
ul.m-doc li.m-doc-collapsible > a:first-child,
ul.m-doc li.m-doc-expansible > a:first-child:hover,
ul.m-doc li.m-doc-expansible > a:first-child:focus,
ul.m-doc li.m-doc-expansible > a:first-child:active,
ul.m-doc li.m-doc-collapsible > a:first-child:hover,
ul.m-doc li.m-doc-collapsible > a:first-child:focus,
ul.m-doc li.m-doc-collapsible > a:first-child:active { color: var(--color); }
a.m-doc-self,
ul.m-doc li.m-doc-expansible > a:first-child::before,
ul.m-doc li.m-doc-collapsible > a:first-child::before { color: var(--article-heading-color); }
a.m-doc-self:hover, a.m-doc-self:focus, a.m-doc-self:active,
ul.m-doc li.m-doc-expansible > a:first-child:hover::before,
ul.m-doc li.m-doc-expansible > a:first-child:focus::before,
ul.m-doc li.m-doc-expansible > a:first-child:active::before,
ul.m-doc li.m-doc-collapsible > a:first-child:hover::before,
ul.m-doc li.m-doc-collapsible > a:first-child:focus::before,
ul.m-doc li.m-doc-collapsible > a:first-child:active::before { color: var(--article-heading-active-color); }
h3 a.m-doc-external { font-weight: normal; }
span.m-doc-wrap-bumper { margin-right: -1rem; }
span.m-doc-wrap {
margin-left: 1rem;
display: inline-block;
vertical-align: text-top;
white-space: pre-line;
max-width: 100%;
}
dl.m-doc dd { margin-bottom: 0.5rem; }
dl.m-doc dd { margin-left: 0; padding-left: 2.5rem; }
dl.m-doc dt:target, dl.m-doc dt:target + dd {
margin-left: -1.0rem;
border-left-style: solid;
border-left-width: 0.25rem;
border-color: var(--article-heading-color);
}
dl.m-doc dt:target { padding-left: 0.75rem; }
dl.m-doc dt:target + dd { padding-left: 3.25rem; }
ul.m-doc {
list-style: none;
margin-left: 1.0375rem;
padding-left: 0.9rem;
border-left-color: var(--line-color);
border-left-width: 0.0625rem;
border-left-style: solid;
}
ul.m-doc li { text-indent: -1rem; padding-left: 1rem; }
ul.m-doc li.m-doc-expansible > ul { display: none; }
ul.m-doc li.m-doc-expansible, ul.m-doc li.m-doc-collapsible { padding-left: 0.6rem; }
ul.m-doc li.m-doc-expansible > ul.m-doc, ul.m-doc li.m-doc-collapsible > ul.m-doc { margin-left: 0.5rem; }
ul.m-doc li.m-doc-expansible > a:first-child::before, ul.m-doc li.m-doc-collapsible > a:first-child::before { background-color: var(--background-color); display: inline-block; width: 0.4rem; font-weight: bold; }
ul.m-doc li.m-doc-expansible > a:first-child::before { content: '⊕'; }
ul.m-doc li.m-doc-collapsible > a:first-child::before { content: '⊖'; }
h1 .m-doc-template, h1 .m-doc-include { font-size: 1.3rem; font-weight: normal; }
h1 .m-doc-include:last-child { margin-bottom: -0.5rem; }
h3 .m-doc-template, h3 .m-doc-include { font-size: 1rem; font-weight: normal; }
.m-doc-template, dl.m-doc dd, ul.m-doc li > span.m-doc { color: var(--dim-color); }
dl.m-doc dd svg.m-math, ul.m-doc li > span.m-doc svg.m-math { fill: var(--dim-color); }
.m-doc-template a, dl.m-doc dd a, ul.m-doc li > span.m-doc a { color: var(--dim-link-color); }
.m-doc-template a:hover, .m-doc-template a:focus, .m-doc-template a:active,
dl.m-doc dd a:hover, dl.m-doc dd a:focus, dl.m-doc dd a:active,
ul.m-doc li > span.m-doc a:hover, ul.m-doc li > span.m-doc a:focus, ul.m-doc li > span.m-doc a:active { color: var(--dim-link-active-color); }
.m-code.m-inverted.m-doc-include > a:link,
.m-code.m-inverted.m-doc-include > a:visited { opacity: 0.6666; }
.m-code.m-inverted.m-doc-include > a:hover,
.m-code.m-inverted.m-doc-include > a:focus,
.m-code.m-inverted.m-doc-include > a:active { opacity: 1; }
article section.m-doc-details > div { margin-top: 0; margin-left: 0; margin-right: 0; position: relative; padding: 1rem; }
article section.m-doc-details > div::before {
position: absolute;
content: ' ';
top: 0;
bottom: 0;
left: 0;
right: 0;
z-index: -1;
border-style: solid;
border-width: 0.125rem;
border-radius: var(--border-radius);
border-color: var(--code-background-color);
}
article section.m-doc-details > div > h3:first-child {
position: relative;
margin: -1rem -1rem 1rem -1rem;
padding: 0.5rem 1rem;
background-color: var(--code-background-color);
border-top-left-radius: var(--border-radius);
border-top-right-radius: var(--border-radius);
border-bottom-left-radius: 0;
border-bottom-right-radius: 0;
}
article section.m-doc-details:target { border-color: transparent; }
article section.m-doc-details:target > div { z-index: 1; }
.m-container-inflatable > .m-row > [class*='m-col-'] section.m-doc-details > div { margin-left: -1rem; margin-right: -1rem; }
.m-container-inflatable section.m-doc-details:target > div > h3:first-child,
.m-container-inflatable section.m-doc-details:target section > div > h3:first-child {
margin-left: -1.0rem;
border-left-style: solid;
border-left-color: var(--article-heading-active-color);
border-left-width: 0.25rem;
padding-left: 0.75rem;
}
.m-container-inflatable section.m-doc-details:target > div::before,
.m-container-inflatable section-dox-details:target section > div.m::before { border-left-width: 0.25rem; border-left-color: var(--article-heading-color); }
a.m-doc-search-icon { padding-left: 1rem; padding-right: 1rem; }
a.m-doc-search-icon svg { fill: var(--header-link-color); }
body > header > nav #m-navbar-collapse a.m-doc-search-icon svg { vertical-align: -5%; }
a.m-doc-search-icon:focus svg, a.m-doc-search-icon:hover svg, a.m-doc-search-icon:active svg { fill: var(--header-link-active-color); }
.m-doc-search {
display: none;
z-index: 10;
position: fixed;
left: 0;
right: 0;
top: 0;
bottom: 0;
background-color: var(--search-overlay-color);
}
.m-doc-search:target { display: block; }
.m-doc-search > a { display: block; position: absolute; left: 0; right: 0; top: 0; bottom: 0; }
.m-doc-search-header { margin-top: 2.5rem; padding: 0.5rem 1rem; height: 2rem; }
.m-doc-search-header > div:first-child { float: right; }
.m-doc-search-content {
background-color: var(--search-background-color);
border-radius: var(--border-radius);
padding: 1rem;
}
.m-doc-search input {
width: 100%;
height: 3rem;
font-size: 1.2rem;
border-width: 0;
color: var(--color);
background-color: var(--default-filled-background-color);
border-radius: var(--border-radius);
margin-bottom: 1rem;
padding: 0 1rem;
}
.m-doc-search #search-notfound { display: none; }
.m-doc-search ul#search-results {
list-style-type: none;
padding-left: 0;
max-height: calc(100vh - 12.5rem);
overflow-y: auto;
display: none;
}
.m-doc-search ul#search-results li a {
display: block;
padding-left: 1rem;
padding-right: 1rem;
text-decoration: none;
width: 100%;
line-height: 1.5rem;
color: var(--color);
}
.m-doc-search ul#search-results li a > div { white-space: nowrap; overflow: hidden; }
.m-doc-search ul#search-results li a > div:not(.m-doc-search-alias) { direction: rtl; }
.m-doc-search ul#search-results li a .m-label { float: right; line-height: 1rem; margin-top: 0.1rem; margin-left: 0.25rem; }
.m-doc-search ul#search-results li a .m-label.m-flat { margin-right: -0.75rem; }
.m-doc-search ul#search-results li#search-current a { background-color: var(--default-filled-background-color); }
.m-doc-search ul#search-results li#search-current.m-doc-search-copied a { background-color: var(--success-filled-background-color); }
.m-doc-search-typed { color: var(--link-color); }
.m-doc-search input[type="search"] { -webkit-appearance: textfield; }
.m-doc-search input[type="search"]::-webkit-search-decoration,
.m-doc-search input[type="search"]::-webkit-search-cancel-button,
.m-doc-search input[type="search"]::-webkit-search-results-button,
.m-doc-search input[type="search"]::-webkit-search-results-decoration { display: none; }
/*==== poxy-overrides.css ============================================================================================*/
html { height: 100%; scroll-padding-top: 4em; }
body { min-height: 100%; }
body { display: flex; flex-direction: column; }
body > header { position: sticky; top: 0; left: 0; right: 0; z-index: 6; }
body > main { flex: 1 0 auto; }
body > footer { flex-shrink: 0; }
body > header,
body > header * { white-space: nowrap; }
a { text-decoration: none !important; }
a:hover { text-decoration: underline !important; }
article div > section { margin-top: 2.5rem; }
article div > section:first-of-type { margin-top: initial; }
article div > section > section { margin-top: 2.25rem; }
article div > section > section:first-of-type { margin-top: initial; }
a.poxy-external { font-weight: normal; }
pre.m-code a,
pre.m-console a { font-weight: inherit !important; color: inherit !important; }
body > header > nav .m-thin { margin-left: 0.5em; }
body > header > nav .poxy-icon img,
body > header > nav .poxy-icon svg { width: 1.5rem !important; height: 1.5rem !important; vertical-align: -18.5%; }
body > header > nav #m-navbar-collapse a.m-doc-search-icon svg { width: 1.25rem !important; height: 1.25rem !important; vertical-align: -12.5%; }
body > header > nav a#m-navbar-brand svg,
body > header > nav #m-navbar-brand a svg { width: 1.75rem; height: 1.75rem; vertical-align: -22.5%; margin-right: 0.5rem; }
body > header > nav a.poxy-icon.theme:hover,
body > header > nav #m-navbar-current:hover {
color: var(--header-link-active-color) !important;
border-color: var(--header-link-active-color) !important;
background-color: var(--header-link-active-background-color) !important;
}
@media screen and (max-width: 768px) {
body > header > nav .m-thin,
body > header > nav .repo { display: none; }
}
body > header > nav a:hover { text-decoration: none !important; }
.m-doc-details div > h4,
.m-doc-details div > h5,
.m-doc-details div > h6,
.m-doc-details div > table.m-table th,
.m-doc-details div > table.m-table td > h3,
.m-doc-details div > table.m-table td > h4,
.m-doc-details div > table.m-table td > h5,
.m-doc-details div > table.m-table td > h6,
.m-doc-details div > table.m-table td > strong > em,
.m-doc-details div > table.m-table td > p > strong > em { font-style: normal; color: var(--article-heading-color); }
.m-doc-details div > table.m-table td > strong > em,
.m-doc-details div > table.m-table td > p > strong > em { display: block; }
.m-doc-details div > table.m-table td > strong:not(:first-child) > em,
.m-doc-details div > table.m-table td > p:not(:first-child) > strong > em { margin-top: 1rem; }
#poxy-badges {
--extra-width: 2rem;
text-align: center;
line-height: 1.75rem;
padding-bottom: 1.25rem;
margin-left: calc(var(--extra-width) * -0.5);
margin-right: calc(var(--extra-width) * -0.5);
margin-top: -0.5rem;
}
#poxy-badges > span { display: inline-block; }
#poxy-badges > span > a,
#poxy-badges > span > svg,
#poxy-badges > span > img { margin-left: 0.2rem; margin-right: 0.2rem; }
h1 span.m-thin { color: var(--dim-color); }
#poxy-main-banner {
margin-left: -1rem !important;
margin-right: -1rem !important;
margin-top: -1.75rem !important;
max-width: calc(100% + 2rem) !important;
}
@media (min-width: 992px) {
svg#poxy-main-banner.poxy-injected-svg { padding: 1.5rem; }
}
@media (min-width: 300px) and (max-width: 992px) {
svg#poxy-main-banner.poxy-injected-svg { padding: 1rem; }
}
.m-doc-details div h3 { overflow: auto; }
h1 .m-doc-include,
h3 .m-doc-include { float: right; }
h1 .m-doc-include *,
h3 .m-doc-include * { opacity: 1 !important; }
h1 .m-doc-include .cp,
h3 .m-doc-include .cp { color: var(--dim-color); }
pre .poxy-godbolt,
code .poxy-godbolt { font-family: "Source Sans Pro", sans-serif; }
pre p.poxy-godbolt,
code p.poxy-godbolt { text-align: center; padding: 0rem; text-indent: 0rem; float: right; }
pre p.poxy-godbolt a.poxy-godbolt,
code p.poxy-godbolt a.poxy-godbolt { padding: 0.5rem; display: inline-block; }
@media screen and (max-width: 768px) {
pre p.poxy-godbolt,
code p.poxy-godbolt { display: none; }
}
h2:last-child,
h3:last-child,
h4:last-child,
h5:last-child,
h6:last-child { margin-bottom: 0rem; }
.m-doc-details table img.m-image { margin-left: inherit; }
@media screen and (min-width: 1300px) {
:root { --wide-page-left-offset: -160px; }
#poxy-toc {
position: fixed;
top: 5rem;
left: calc(50% + 470px + var(--wide-page-left-offset));
min-width: 200px;
z-index: 5;
margin: 0px 20px 0px 0px !important;
background-color: var(--background-color);
overflow-y: auto;
max-height: calc(100% - 7rem);
}
header nav > .m-container,
footer nav > .m-container { width: 100%; }
main article > .m-container > .m-row { margin-left: var(--wide-page-left-offset); margin-right: calc(var(--wide-page-left-offset) * -1); }
}
.m-block.m-dim pre.m-code,
.m-note.m-dim pre.m-code { opacity: 0.85; }
.m-block li,
.m-note li,
section > ul li,
section > ol li { margin-bottom: 0.2rem; }
.m-block li:last-child,
.m-note li:last-child,
section > ul li:last-child,
section > ol li:last-child { margin-bottom: initial; }
.m-block li > ul > li:first-child,
.m-note li > ul > li:first-child,
.m-block li > ol > li:first-child,
.m-note li > ol > li:first-child { margin-top: 0.2rem; }
article section.m-doc-details > div > h3:first-child { background-color: var(--detail-section-header-color); }
article section.m-doc-details > div::before {
border-color: var(--detail-section-header-color);
background-color: var(--detail-section-background-color);
}
ul.m-doc > li.m-doc-collapsible,
ul.m-doc > li.m-doc-collapsible > a:first-child,
ul.m-doc > li.m-doc-collapsible li { color: var(--dim-link-color) !important; }
pre.m-code + pre.m-console { margin-top: -1rem; font-size: 0.8rem; }
.m-note pre.m-code + pre.m-console { color: var(--console-color); background-color: var(--console-background-color); }
pre.poxy-impl,
code.poxy-impl {
color: var(--code-color-comments) !important;
padding: 0rem !important;
margin: 0rem 0.2rem !important;
font-weight: normal;
}
article section:target > .m-code,
article section:target > .m-console,
article section:target > .m-note,
article section:target > .m-block,
article section:target > .m-container-inflate > .m-code,
article section:target > .m-container-inflate > .m-console,
article section:target > .m-container-inflate > .m-note,
article section:target > .m-container-inflate > .m-block,
article section:target section.m-doc-details > div > h3:first-child,
article section.m-doc-details:target > div > h3:first-child { border-color: var(--article-heading-color) !important; }
article section:target section.m-doc-details > div > h3:first-child { border-left-style: solid; border-left-width: 0.25rem; }
.m-label:not(.m-flat) { color: var(--background-color) !important; }
figure.m-figure > figcaption {
font-weight: initial !important;
font-size: 1rem !important;
text-align: center;
margin-top: initial;
}
.m-success:not(.m-note, .m-button) a { color: var(--success-color); }
.m-success:not(.m-note, .m-button) a:hover,
.m-success:not(.m-note, .m-button) a:focus,
.m-success:not(.m-note, .m-button) a:active { color: var(--success-link-active-color); }
.m-warning:not(.m-note, .m-button) a { color: var(--warning-color); }
.m-warning:not(.m-note, .m-button) a:hover,
.m-warning:not(.m-note, .m-button) a:focus,
.m-warning:not(.m-note, .m-button) a:active { color: var(--warning-link-active-color); }
.m-danger:not(.m-note, .m-button) a { color: var(--danger-color); }
.m-danger:not(.m-note, .m-button) a:hover,
.m-danger:not(.m-note, .m-button) a:focus,
.m-danger:not(.m-note, .m-button) a:active { color: var(--danger-link-active-color); }
.m-info:not(.m-note, .m-button) a { color: var(--info-color); }
.m-info:not(.m-note, .m-button) a:hover,
.m-info:not(.m-note, .m-button) a:focus,
.m-info:not(.m-note, .m-button) a:active { color: var(--info-link-active-color); }
.m-doc-template-params.m-doc-template-long { display: block; padding-left: 1rem; }
.m-doc-template-params.m-doc-template-long .m-doc-template-param::before { content: ""; display: block; }
.m-doc-details .m-doc-template .m-doc-template-parent,
.m-doc-details .m-doc-template .m-doc-template-parent + br { display: none; }
section.m-doc-details div .m-table.m-fullwidth.m-flat tbody td:first-of-type wbr { display: none; }
.poxy-about-the-author { margin-top: 4rem; }
.poxy-about-the-author .poxy-socials { display: block; padding-top: 0.5rem; }
.poxy-about-the-author img.poxy-icon,
.poxy-about-the-author svg.poxy-icon { max-width: 1.5rem; max-height: 1.5rem; margin-right: 0.5rem; }
header nav #m-navbar-collapse li a.sponsor:hover { border-color: var(--sponsor-color) !important; }
header nav a.sponsor:hover,
footer nav a.sponsor:hover,
a.poxy-icon.sponsor:hover { color: var(--sponsor-color) !important; }
main article a.poxy-named-requirement { font-style: italic; }

